-- 调试界面
Lua_DevelopDebugWindow = class("Lua_DevelopDebugWindow", Lua_Window)
function Lua_DevelopDebugWindow:ctor()
	self:superCall("ctor");

	self.w = 0;
	self.h = 0;
	self.layer = MainWinDefine.MAX_TOP_LAYER;
	self.windowName = "Lua_DevelopDebugWindow";
	self.skinName = "DevelopDebugWindow_skin";
	self.showBlackMask = false;
	self.isClickClose = false;
end

function Lua_DevelopDebugWindow:buildShowItem()
	self:superCall("buildShowItem");
	GlobalVar.bDevelopDebugGM = true;
	self.operatingClientDataTab = DataCenter.loginData.operatingClientDataTab;
	self.descTxt.text = "";
	self.proityTxt.text = "0";
	self.proityTxt:addValidateInfo("0", "9");
	self.cmdTxt.text = "";
	self.param1Txt.text = "";
	self.param2Txt.text = "";
	self.param3Txt.text = "";
	self.param4Txt.text = "";
	self.param5Txt.text = "";

	self.dragList = Lua_DragList.new(self.content, 720, 250, Lua_AxisDefine.Vertical);
	self.dragList:setListCell(Lua_DevelopDebugItem, 720, 60, 1);
	self.dragList:setLocation(0, 232, 0);

	self.sureBtn:addClickFuntion(self, self.onSureBtnClick);
	self.saveBtn:addClickFuntion(self, self.onSaveBtnClick);
	self:addLuaEvent("Select_Develop_Debug", self, self.onSelectCellClick);
	self:addLuaEvent("Delete_Develop_Debug", self, self.onDelCellClick);
	self:parseGlobalClientData();
end

function Lua_DevelopDebugWindow:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end

	if self.clientData ~= nil then table.clear(self.clientData); end
	if self.clientDataArr ~= nil then self.clientDataArr:clear(); end
	self:superCall("dispose");
end

function Lua_DevelopDebugWindow:generateGMStr(showTips, isOperating)
	local desc = self.descTxt.text;
	if strIsNullOrEmpty(desc) then
		if showTips then OperateAlert.show("指令描述为空"); end
		return;
	end

	local gm = self.cmdTxt.text;
	if strIsNullOrEmpty(desc) then
		if showTips then OperateAlert.show("测试命令为空"); end
		return;
	end

	local proity = 0;
	local proityStr = self.proityTxt.text;
	if strIsNullOrEmpty(proity) then
		self.proityTxt.text = "0";
	else
		proity = tonumber(proityStr);
	end

	local descOperate = nil;
	local param1 = self.param1Txt.text;
	local param2 = self.param2Txt.text; 
	local param3 = self.param3Txt.text;
	local param4 = self.param4Txt.text;
	local param5 = self.param5Txt.text;
	if self.clientData == nil then self.clientData = {}; end 
	if isOperating then self.operatingClientDataTab[desc] = true; end
	if self.operatingClientDataTab[desc] then descOperate = "(执行中)"..desc; end
	local tab = {desc = desc, descOperate = descOperate, proity = proity, gm = gm, param1 = param1, param2 = param2, param3 = param3, param4 = param4, param5 = param5};
	if self.clientData[desc] == nil then
		if self.clientDataArr == nil then self.clientDataArr = Array(); end 
		self.clientDataArr:add(tab);
	else
		local bHas = false;
		for i = 1, self.clientDataArr:getSize() do
			if self.clientDataArr[i].desc == desc then
				bHas = true;
				self.clientDataArr[i] = tab;
				break;
			end
		end
		if not bHas then
			self.clientDataArr:add(tab);
		end
	end

	self.clientData[desc] = tab;
	self.clientDataArr:sort("proity");
	self.dragList:setArrayData(self.clientDataArr);
	local tokenstr = decodeTabToJson(self.clientData);
	if isOperating then
		local cmdStr = decodeTabToJson(tab);
		MsgUtil.callFunc("DEVELOP_DEBUG_OPERATE_SURE", cmdStr);
	end
	return tokenstr;
end

function Lua_DevelopDebugWindow:parseGlobalClientData()
	if self.clientData ~= nil then table.clear(self.clientData); end
	if self.clientDataArr ~= nil then self.clientDataArr:clear(); end
	local str = DataCenter.loginData.globalClientData;
	if strIsNullOrEmpty(str) then
		self.dragList:setArrayData(self.clientDataArr);
		return;
	end

	local data = decodeJson(str);
	if data ~= nil then
    	if self.clientData == nil then self.clientData = {}; end
    	if self.clientDataArr == nil then self.clientDataArr = Array(); end 
		for k, v in pairs(data) do
			if self.clientData[k] == nil then 
				local descOperate = nil;
				if self.operatingClientDataTab[k] then
					v.descOperate = "(执行中)"..k;
				else
					v.descOperate = nil;
				end
				self.clientData[k] = v;
				self.clientDataArr:add(v);
			end
	    end  
	end
	self.dragList:setArrayData(self.clientDataArr);
end

function Lua_DevelopDebugWindow:onSureBtnClick()
	local str = self:generateGMStr(true, true);
	if strIsNullOrEmpty(str) then
		OperateAlert.show("请执行正确的指令内容");
		return;
	end
	self:saveGm(str);
end

function Lua_DevelopDebugWindow:onSaveBtnClick()
	local str = self:generateGMStr(true);
	if strIsNullOrEmpty(str) then
		OperateAlert.show("请保存正确的指令内容");
		return;
	end
	self:saveGm(str);
end

function Lua_DevelopDebugWindow:onSelectCellClick(obj)
	if obj == nil then return; end
	self.descTxt.text = obj.desc;
	self.proityTxt.text = tostring(obj.proity);
	self.cmdTxt.text = obj.gm;
	self.param1Txt.text = obj.param1 == nil and "" or obj.param1;
	self.param2Txt.text = obj.param2 == nil and "" or obj.param2;
	self.param3Txt.text = obj.param3 == nil and "" or obj.param3;
	self.param4Txt.text = obj.param4 == nil and "" or obj.param4;
	self.param5Txt.text = obj.param5 == nil and "" or obj.param5;
end

function Lua_DevelopDebugWindow:onDelCellClick(obj)
	-- {desc = desc, proity = proity, gm = gm, param1 = param1, param2 = param2, param3 = param3, param4 = param4, param5 = param5};
	if self.clientData == nil then return; end
	if obj == nil then return; end
	local desc = obj.desc;
	if strIsNullOrEmpty(desc) then return; end
	if self.clientData[desc] ~= nil then
		self.clientData[desc] = nil;
		for i = 1, self.clientDataArr:getSize() do
			if self.clientDataArr[i].desc == desc then
				local tab = self.clientDataArr[i];
				local cmdStr = decodeTabToJson(tab);
				MsgUtil.callFunc("DEVELOP_DEBUG_OPERATE_CANCLE", cmdStr);
				self.clientDataArr:remove(i);
				self.operatingClientDataTab[desc] = false;
				self.dragList:setArrayData(self.clientDataArr);
				local tokenstr = decodeTabToJson(self.clientData);
				self:saveGm(tokenstr);
				return;
			end
		end
	end
end

function Lua_DevelopDebugWindow:saveGm(str)
	DataCenter.loginData.globalClientData = str;
	local cmd = ProtoPublic_pb.Proto10182002();
    cmd.key = 1;
    cmd.global_data = str;
    sendMsg(10182002, cmd);
end

















Lua_DevelopDebugItem = class("Lua_DevelopDebugItem", Lua_ListCell);
function Lua_DevelopDebugItem:ctor(p)
	self:superCall("ctor", p, "DevelopDebugItem_skin");
	self.bOperating = false;
end

function Lua_DevelopDebugItem:buildShowItem()
	self:superCall("buildShowItem");
	self.delBtn:addClickFuntion(self, self.onDelBtnClick);
	self.selectBtn:addClickFuntion(self, self.onSelectBtnClick);
end

function Lua_DevelopDebugItem:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_DevelopDebugItem:setData(data)
	self.data = data;
	if data.descOperate ~= nil then
		self.descTxt.text = data.descOperate;
		self.selectBtn.label = "取消";
		self.bOperating = true;
	else
		self.descTxt.text = data.desc;
		self.selectBtn.label = "选择";
		self.bOperating = false;
	end
	self.proityTxt.text = data.proity;
end

function Lua_DevelopDebugItem:onSelectBtnClick()
	if self.bOperating then
		local cmdStr = decodeTabToJson(self.data);
		self.data.descOperate = nil;
		self.descTxt.text = self.data.desc;
		self.selectBtn.label = "选择";
		self.bOperating = false;
		MsgUtil.callFunc("DEVELOP_DEBUG_OPERATE_CANCLE", cmdStr);
	else
		Lua_MsgUtil.callFunc("Select_Develop_Debug", self.data);
	end
end

function Lua_DevelopDebugItem:onDelBtnClick()
	Lua_MsgUtil.callFunc("Delete_Develop_Debug", self.data);
end