Lua_GuideTestWindow = class("Lua_GuideTestWindow", Lua_Window)
function Lua_GuideTestWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.MAX_TOP_LAYER; 
	self.windowName = "Lua_GuideTestWindow";
	self.skinName = "GuideTestWindow_skin";
end

function Lua_GuideTestWindow:buildShowItem()
	self:superCall("buildShowItem");

	self:onUpdatePopupWinsTips();
	self.winBg.clickScale = false;
	self.winBg:addMousDownFuntion(self, self.onMouseDownHandle);
	self.winBg:addMouseUpFuntion(self, self.onMouseUpHandle);
	self.guideIdTxt.text = DataCenter.guideData.curGuideId;
	self.guideStepTxt.text = DataCenter.guideData.curGuideStep;
	self.stopGuideBtn.label = DataCenter.guideData.bOpenGuide and "关闭引导" or "开启引导";
	self.playBtn:addClickFuntion(self, self.onPlayBtnClick);
	self.closeGuideBtn:addClickFuntion(self, self.onCloseGuideBtnClick);
	self.stopGuideBtn:addClickFuntion(self, self.onStopGuideBtnClick);
	self.refreshBtn:addClickFuntion(self, self.onRefreshBtnClick);
	self.skipGuideBtn:addClickFuntion(self, self.onSkipGuideBtnClick);
	self.changeGuideBtn:addClickFuntion(self, self.onChangeGuideBtnClick);
	self.calculateTimeBtn:addClickFuntion(self, self.onCalculateTimeBtnClick);
	self.completeAllGuideBtn:addClickFuntion(self, self.onCompleteGuideClick);
	
	self:addLuaEvent("Guide_Condition_Update", self, self.onUpdatePopupWinsTips);
end

function Lua_GuideTestWindow:dispose()
	self:endTimer();
	self:superCall("dispose");
end

function Lua_GuideTestWindow:onMouseDownHandle(go)
	self.canDrag = true;
	self.clickTime = getTime();
	self.startMouseX = CommonUtil.mousePositionX;
	self.startMouseY = CommonUtil.mousePositionY;
	self:startTimer();
end

function Lua_GuideTestWindow:onMouseUpHandle(go)
	self.canDrag = false;
	self:endTimer();
end

function Lua_GuideTestWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_GuideTestWindow", 0.01, self, self.onTimer, nil, -1);
	end
end

function Lua_GuideTestWindow:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_GuideTestWindow:onTimer()
	if self.canDrag ~= true then
		return
	end

    local dx = CommonUtil.mousePositionX - self.startMouseX;
    local dy = CommonUtil.mousePositionY - self.startMouseY;
    self.startMouseX = CommonUtil.mousePositionX;
    self.startMouseY = CommonUtil.mousePositionY;

    local vec = self.content.transform.localPosition;
    local targetX = vec.x + dx;
    local vw = UnityEngine.Screen.width / GlobalVar.scaleRatio;
    if targetX < -(vw - self.w)/2 or targetX > (vw - self.w)/2 then
    	return;
    end

    local targetY = vec.y + dy;
    local vh = UnityEngine.Screen.height / GlobalVar.scaleRatio;
    if targetY < -(vh - self.h)/2 or targetY > (vh - self.h)/2 then
    	return;
    end

    LuaUtil.setObjPos(self.content, targetX, targetY, vec.z);
end

function Lua_GuideTestWindow:onUpdatePopupWinsTips(conditionType)
	if conditionType == nil or conditionType == Lua_GuideDefine.Trigger_Condition_OpenWin then
		self.popupWinTips.text = "当前后台弹框列表：" .. DataCenter.popupWinManager:generatePopupWinsStr();
	end
end

function Lua_GuideTestWindow:onPlayBtnClick(go)
	local gid = self.guideIdTxt.text;
	if strIsNullOrEmpty(gid) then
		OperateAlert.show("请输入引导id");
		return;
	end

	gid = tonumber(gid);
	local cfg = DataCenter.guideUtil:getGuideCfg(gid);
	if cfg == nil then
		OperateAlert.show(gid.."引导不存在");
		return;
	end

	local step = self.guideStepTxt.text;
	step = strIsNullOrEmpty(step) and 1 or tonumber(step);
	step = step == 0 and 1 or step;
	local stepCfg = DataCenter.guideUtil:getGuideStepCfg(gid, step);
	if stepCfg == nil then
		OperateAlert.show(gid.."引导不存在第"..step.."步骤数据");
		return;
	end

	Lua_WindowUtil.openWin("Lua_GuideWindow", Lua_WinParam.ACTION_OPEN, {guideId = gid, guideStep = step - 1});
	self:hide();
end

function Lua_GuideTestWindow:onCloseGuideBtnClick()
	Lua_WindowUtil.openWin("Lua_GuideWindow", Lua_WinParam.ACTION_CLOSE);
end

function Lua_GuideTestWindow:onStopGuideBtnClick()
	DataCenter.guideData.bOpenGuide = not DataCenter.guideData.bOpenGuide;
	self.stopGuideBtn.label = DataCenter.guideData.bOpenGuide and "关闭引导" or "开启引导";
end

function Lua_GuideTestWindow:onRefreshBtnClick()
	if not DataCenter.bConfigLoaded then
		return;
	end

	if not NoServerUtil.isLocalRes then
		OperateAlert.show("非读取本地资源，暂不支持刷新");
		return;
	end

	ConfigManager.getInstance():refreshConfigs(ServerConfig.cdn_server.."/"..UrlManager.resName.."/configs/guide.lua");
	ConfigManager.getInstance():refreshConfigs(ServerConfig.cdn_server.."/"..UrlManager.resName.."/configs/guide_step.lua");
	DataCenter.guideUtil._guideConfig = nil;
	DataCenter.guideUtil._guideStepConfig = nil;
	DataCenter.guideData:disposeTest();
	DataCenter.guideData:checkGuide();
	DataCenter.guideData:checkPlayGuide();
end

-- 跳过当前引导
function Lua_GuideTestWindow:onSkipGuideBtnClick()
	Lua_MsgUtil.callFunc("Guide_Skip_CurGuiding");
end

-- 修改服务端引导步骤
function Lua_GuideTestWindow:onChangeGuideBtnClick()
	local gid = self.guideIdTxt.text;
	if strIsNullOrEmpty(gid) then
		OperateAlert.show("请输入引导id");
		return;
	end

	gid = tonumber(gid);
	local cfg = DataCenter.guideUtil:getGuideCfg(gid);
	if cfg == nil then
		OperateAlert.show(gid.."引导不存在");
		return;
	end

	local step = self.guideStepTxt.text;
	step = strIsNullOrEmpty(step) and 1 or tonumber(step);
	step = step == 0 and 1 or step;
	local stepCfg = DataCenter.guideUtil:getGuideStepCfg(gid, step);
	if stepCfg == nil then
		OperateAlert.show(gid.."引导不存在第"..step.."步骤数据");
		return;
	end

	DataCenter.guideData:testUpdateServerInfo(gid, step);
end

-- 引导对话时长
function Lua_GuideTestWindow:onCalculateTimeBtnClick()
	local dialogueContent;
	local gid = self.guideIdTxt.text;

	local cfg = DataCenter.guideUtil:getGuideCfg(tonumber(gid));
	if cfg == nil then
		dialogueContent = gid;
	else
		local step = self.guideStepTxt.text;
		step = strIsNullOrEmpty(step) and 1 or tonumber(step);
		local stepCfg = DataCenter.guideUtil:getGuideStepCfg(gid, step);
		if stepCfg == nil then
			OperateAlert.show(gid.."引导不存在第"..step.."步骤数据");
			return;
		end
		dialogueContent = stepCfg.dialogContent;
	end
	
	if dialogueContent == nil then
		OperateAlert.show("内容为空");
		return;
	else
		OperateAlert.show(dialogueContent);
	end
	
	local charNum = calculateStrNum(dialogueContent);
	local perTime = self.perTimeTxt.text;
	local totalTime = charNum * perTime;
	self.timeTipsTxt.text = "总时长："..totalTime..", 总字数："..charNum..", 每字播放速度："..perTime.."毫秒/字";
end

-- 完成所有引导
function Lua_GuideTestWindow:onCompleteGuideClick()
	DataCenter.guideData:completeAllGuide();
	DataCenter.guideData.bOpenGuide = false;
	self.stopGuideBtn.label = DataCenter.guideData.bOpenGuide and "关闭引导" or "开启引导";
	Lua_WindowUtil.openWin("Lua_GuideWindow", Lua_WinParam.ACTION_CLOSE);
end