Lua_MainLineDebugWindow = class("Lua_MainLineDebugWindow", Lua_Window)
function Lua_MainLineDebugWindow:ctor()
	self:superCall("ctor");

	self.w = 0;
	self.h = 0;
	self.windowName = "Lua_MainLineDebugWindow";
	self.skinName = "MainLineDebugWindow_skin";
end

function Lua_MainLineDebugWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.winBg.clickScale = false;
	self.winBg:addMousDownFuntion(self, self.onMouseDownHandle);
	self.winBg:addMouseUpFuntion(self, self.onMouseUpHandle);

	self.btnDragRange:addClickFuntion(self, self.onDragRange);
	self.btnCameraInfo:addClickFuntion(self, self.onCameraInfo);
	self.btnCameraLookAt:addClickFuntion(self, self.onCameraLookAt);
	self.btnSure:addClickFuntion(self, self.onBtnSureClick);
end

function Lua_MainLineDebugWindow:dispose()
	self:superCall("dispose");
end

function Lua_MainLineDebugWindow:onMouseDownHandle(go)
    self:onPress(go, true);
end

function Lua_MainLineDebugWindow:onMouseUpHandle(go)
    self:onPress(go, false);
end

function Lua_MainLineDebugWindow:onPress(go, state)
    if state == true then
    	self.clickTime = getTime();
        if self.bDragClick == nil or self.bDragClick == false then
            self.bDragClick = true;
            self.startMouseX = CommonUtil.mousePositionX;
            self.startMouseY = CommonUtil.mousePositionY;
            Lua_CommonUtil.addTimer( "onDebugDragFrame", 0.01, self, self.onDebugDragFrame);
        end   
    else
    	if PlayerData.instance.uiShowState == 0 and getTime() - self.clickTime < 4 then
    		MsgUtil.callFunc("UI_SHOW_STATE");
    	end

        if self.bDragClick ~= nil and self.bDragClick == true then
            self.bDragClick = false;
            Lua_CommonUtil.removeTimer(self, self.onDebugDragFrame);
        end
    end
end

function Lua_MainLineDebugWindow:onDebugDragFrame()
    local dx = CommonUtil.mousePositionX - self.startMouseX;
    local dy = CommonUtil.mousePositionY - self.startMouseY;
    self.startMouseX = CommonUtil.mousePositionX;
    self.startMouseY = CommonUtil.mousePositionY;

    local vec = self.content.transform.localPosition;
    local targetX = vec.x + dx;
    local vw = UnityEngine.Screen.width / GlobalVar.scaleRatio;
    if targetX < -(vw - self.w)/2 or targetX > (vw - self.w)/2 then
    	return;
    end

    local targetY = vec.y + dy;
    local vh = UnityEngine.Screen.height / GlobalVar.scaleRatio;
    if targetY < -(vh - self.h)/2 or targetY > (vh - self.h)/2 then
    	return;
    end

    LuaUtil.setObjPos(self.content, targetX, targetY, vec.z);
end

function Lua_MainLineDebugWindow:onDragRange(go)
	DataCenter.bCameraDragRange = true;
	local x = tonumber(self.dragRangeX.text);
	local y = tonumber(self.dragRangeY.text);
	local cameraViewHandle = GlobalVar.cameraViewHandle;
	cameraViewHandle:updateLimitAngle(0, 360, 0, 360);
	cameraViewHandle:updateLimitDistance(0, 100000);
	LuaUtil.updateMapDragArea(x, y);
end

function Lua_MainLineDebugWindow:onCameraInfo(go)
	MsgUtil.callFunc("SHOW_CAM_INFO");
end

function Lua_MainLineDebugWindow:onCameraLookAt(go)
	MsgUtil.callFunc("SHOW_CAM_LOOKAT");
end

function Lua_MainLineDebugWindow:onBtnSureClick(go)
	local x = tonumber(self.x_left.text);
	local y = tonumber(self.y_left.text);
	local z = tonumber(self.z_left.text);
	local left = Vector3(x, y, z);

	x = tonumber(self.x_right.text);
	y = tonumber(self.y_right.text);
	z = tonumber(self.z_right.text);
	local right = Vector3(x, y, z);

	x = (left.x + right.x) / 2;
	y = (left.y + right.y) / 2;
	z = (left.z + right.z) / 2;
	self.dragCenterPos.text = "["..x..","..y..","..z.."]";

	local r = GlobalVar.mainCamera.transform.right;
	self.rightVector.text = "["..r.x..","..r.y..","..r.z.."]";
end