-- 设置性能
Lua_QualitySettingWindow = class("Lua_QualitySettingWindow", Lua_Window)
function Lua_QualitySettingWindow:ctor()
	self:superCall("ctor");

	self.w = 0;
	self.h = 0;
	self.layer = MainWinDefine.MAX_TOP_LAYER;
	self.windowName = "Lua_QualitySettingWindow";
	self.skinName = "QualitySettingWindow_skin";
	self.showBlackMask = false;
	self.isClickClose = false;
end

function Lua_QualitySettingWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.winBg.clickScale = false;
	self.winBg:addMousDownFuntion(self, self.onMouseDownHandle);
	self.winBg:addMouseUpFuntion(self, self.onMouseUpHandle);
	self.deviceQuality = DeviceQuality.instance;
	self:checkFps();

	self.renderScale.text = self.deviceQuality.renderScale;
	self.renderScale:onEndEdit(self, self.onRenderScaleEditEnd);

	self.fps30:addBoxChange(self, self.onfps30BoxClick);
	self.fps45:addBoxChange(self, self.onfps45BoxClick);
	self.fps60:addBoxChange(self, self.onfps60BoxClick);

	self.vsync0:addBoxChange(self, self.onvsync0BoxClick);
	self.vsync1:addBoxChange(self, self.onvsync1BoxClick);
	self.vsync2:addBoxChange(self, self.onvsync2BoxClick);

	local msaaSampleCount = self.deviceQuality.msaaSampleCount;
	self.anti0.selected = msaaSampleCount == 0;
	self.anti2.selected = msaaSampleCount == 2;
	self.anti4.selected = msaaSampleCount == 4;
	self.anti8.selected = msaaSampleCount == 8;
	self.anti0:addBoxChange(self, self.onanti0BoxClick);
	self.anti2:addBoxChange(self, self.onanti2BoxClick);
	self.anti4:addBoxChange(self, self.onanti4BoxClick);
	self.anti8:addBoxChange(self, self.onanti8BoxClick);

	local supportsMainLightShadows = self.deviceQuality.supportsMainLightShadows;
	local mainLightShadowmapResolution = self.deviceQuality.mainLightShadowmapResolution;
	if supportsMainLightShadows then
		self.mainlightshadow0.selected = false;
		self.mainlightshadow1.selected = mainLightShadowmapResolution == 256;
		self.mainlightshadow2.selected = mainLightShadowmapResolution == 512;
		self.mainlightshadow3.selected = mainLightShadowmapResolution == 1024;
		self.mainlightshadow4.selected = mainLightShadowmapResolution == 2048;
	else
		self.mainlightshadow0.selected = true;
		self.mainlightshadow1.selected = false;
		self.mainlightshadow2.selected = false;
		self.mainlightshadow3.selected = false;
		self.mainlightshadow4.selected = false;
	end
	self.mainlightshadow0:addBoxChange(self, self.onmainlightshadow0BoxClick);
	self.mainlightshadow1:addBoxChange(self, self.onmainlightshadow1BoxClick);
	self.mainlightshadow2:addBoxChange(self, self.onmainlightshadow2BoxClick);
	self.mainlightshadow3:addBoxChange(self, self.onmainlightshadow3BoxClick);
	self.mainlightshadow4:addBoxChange(self, self.onmainlightshadow4BoxClick);


	local supportsAdditionalLightShadows = self.deviceQuality.supportsAdditionalLightShadows;
	local additionalLightsShadowmapResolution = self.deviceQuality.additionalLightsShadowmapResolution;
	if supportsAdditionalLightShadows then
		self.addilightshadow0.selected = false;
		self.addilightshadow1.selected = additionalLightsShadowmapResolution == 256;
		self.addilightshadow2.selected = additionalLightsShadowmapResolution == 512;
		self.addilightshadow3.selected = additionalLightsShadowmapResolution == 1024;
		self.addilightshadow4.selected = additionalLightsShadowmapResolution == 2048;
	else
		self.addilightshadow0.selected = true;
		self.addilightshadow1.selected = false;
		self.addilightshadow2.selected = false;
		self.addilightshadow3.selected = false;
		self.addilightshadow4.selected = false;
	end
	self.addilightshadow0:addBoxChange(self, self.onaddilightshadow0BoxClick);
	self.addilightshadow1:addBoxChange(self, self.onaddilightshadow1BoxClick);
	self.addilightshadow2:addBoxChange(self, self.onaddilightshadow2BoxClick);
	self.addilightshadow3:addBoxChange(self, self.onaddilightshadow3BoxClick);
	self.addilightshadow4:addBoxChange(self, self.onaddilightshadow4BoxClick);

	self.post.selected = self.deviceQuality.bEnablePostProcessing;
	self.post:addBoxChange(self, self.onpostBoxClick);

	local skinWeights =  self.deviceQuality.skinWeights;
	self.bone1.selected = skinWeights == 1;
	self.bone2.selected = skinWeights == 2;
	self.bone4.selected = skinWeights == 4;
	self.bonemax.selected = skinWeights == 255;
	self.bone1:addBoxChange(self, self.onbone1BoxClick);
	self.bone2:addBoxChange(self, self.onbone2BoxClick);
	self.bone4:addBoxChange(self, self.onbone4BoxClick);
	self.bonemax:addBoxChange(self, self.onbonemaxBoxClick);

	self.softshadow.selected = self.deviceQuality.supportsSoftShadows;
	self.softshadow:addBoxChange(self, self.onsoftshadowBoxClick);
end

function Lua_QualitySettingWindow:dispose()
	
	self:superCall("dispose");
end

function Lua_QualitySettingWindow:onMouseDownHandle(go)
	self:onPress(go, true);
end

function Lua_QualitySettingWindow:onMouseUpHandle(go)
	self:onPress(go, false);
end

function Lua_QualitySettingWindow:onPress(go, state)
    if state == true then
    	self.clickTime = getTime();
        if self.bDragClick == nil or self.bDragClick == false then
            self.bDragClick = true;
            self.startMouseX = CommonUtil.mousePositionX;
            self.startMouseY = CommonUtil.mousePositionY;
            Lua_CommonUtil.addTimer("Lua_QualitySettingWindow", 0.01, self, self.onDragFrame);
        end   
    else
        if self.bDragClick ~= nil and self.bDragClick == true then
            self.bDragClick = false;
            Lua_CommonUtil.removeTimer(self, self.onDragFrame);
        end
    end
end

function Lua_QualitySettingWindow:onDragFrame()
	local dx = CommonUtil.mousePositionX - self.startMouseX;
	local dy = CommonUtil.mousePositionY - self.startMouseY;
	self.startMouseX = CommonUtil.mousePositionX;
	self.startMouseY = CommonUtil.mousePositionY;

	local vec = self.content.transform.localPosition;
	local targetX = vec.x + dx;
	local vw = UnityEngine.Screen.width / GlobalVar.scaleRatio;
	if targetX < -(vw - self.w) / 2 or targetX > (vw - self.w) / 2 then
		return;
	end

	local targetY = vec.y + dy;
	local vh = UnityEngine.Screen.height / GlobalVar.scaleRatio;
	if targetY < -(vh - self.h) / 2 or targetY > (vh - self.h) / 2 then
		return;
	end

	LuaUtil.setObjPos(self.content, targetX, targetY, vec.z);
end

function Lua_QualitySettingWindow:onRenderScaleEditEnd()
	local str = self.renderScale.text;
	local num = 1;
	if str ~= nil then
		num = tonumber(str);
	end
	if num == nil then
		num = 1;
	elseif num <= 0 then
		num = 1;
	elseif num >= 2 then
		num = 2;
	end

	str = tostring(num);
	self.renderScale.text = str;
	self.deviceQuality:setRenderScale(num);
	return true;
end

function Lua_QualitySettingWindow:onfps30BoxClick(selected)
	if selected then
		if UnityEngine.QualitySettings.vSyncCount > 0 then
			self.fps30.selected = false;
			return;
		end

		self.fps45.selected = false;
		self.fps60.selected = false;
		MsgUtil.callFunc("FPS_UPDATE", 30);
	else
		self.fps30.selected = true;
	end
end

function Lua_QualitySettingWindow:onfps45BoxClick(selected)
	if selected then
		if UnityEngine.QualitySettings.vSyncCount > 0 then
			self.fps45.selected = false;
			return;
		end

		self.fps30.selected = false;
		self.fps60.selected = false;
		MsgUtil.callFunc("FPS_UPDATE", 45);
	else
		self.fps45.selected = true;
	end
end

function Lua_QualitySettingWindow:onfps60BoxClick(selected)
	if selected then
		if UnityEngine.QualitySettings.vSyncCount > 0 then
			self.fps60.selected = false;
			return;
		end

		self.fps45.selected = false;
		self.fps30.selected = false;
		MsgUtil.callFunc("FPS_UPDATE", 60);
	else
		self.fps60.selected = true;
	end
end

function Lua_QualitySettingWindow:onvsync0BoxClick(selected)
	if selected then
		self.vsync1.selected = false;
		self.vsync2.selected = false;
		UnityEngine.QualitySettings.vSyncCount = 0;
		self:checkFps();
	else
		self.vsync0.selected = true;
	end
end

function Lua_QualitySettingWindow:onvsync1BoxClick(selected)
	if selected then
		self.vsync0.selected = false;
		self.vsync2.selected = false;
		UnityEngine.QualitySettings.vSyncCount = 1;
		self.fps45.selected = false;
		self.fps30.selected = false;
		self.fps60.selected = false;
	else
		self.vsync1.selected = true;
	end
end


function Lua_QualitySettingWindow:onvsync2BoxClick(selected)
	if selected then
		self.vsync1.selected = false;
		self.vsync0.selected = false;
		UnityEngine.QualitySettings.vSyncCount = 2;
		self.fps45.selected = false;
		self.fps30.selected = false;
		self.fps60.selected = false;
	else
		self.vsync2.selected = true;
	end
end


function Lua_QualitySettingWindow:checkFps()
	if UnityEngine.QualitySettings.vSyncCount > 0 then
		self.fps45.selected = false;
		self.fps30.selected = false;
		self.fps60.selected = false;

		self.vsync0.selected = false;
		self.vsync1.selected = UnityEngine.QualitySettings.vSyncCount == 1;
		self.vsync2.selected = UnityEngine.QualitySettings.vSyncCount == 2;
	else
		local fps = UnityEngine.Application.targetFrameRate;
		self.fps45.selected = fps == 45;
		self.fps30.selected = fps == 30;
		self.fps60.selected = fps == 60;

		self.vsync0.selected = true;
		self.vsync1.selected = false;
		self.vsync2.selected = false;
	end
end

function Lua_QualitySettingWindow:onanti0BoxClick(selected)
	if selected then
		self.anti2.selected = false;
		self.anti4.selected = false;
		self.anti8.selected = false;
		self.deviceQuality.msaaSampleCount = 0;
	else
		self.anti0.selected = true;
	end
end

function Lua_QualitySettingWindow:onanti2BoxClick(selected)
	if selected then
		self.anti0.selected = false;
		self.anti4.selected = false;
		self.anti8.selected = false;
		self.deviceQuality.msaaSampleCount = 2;
	else
		self.anti2.selected = true;
	end
end

function Lua_QualitySettingWindow:onanti4BoxClick(selected)
	if selected then
		self.anti2.selected = false;
		self.anti0.selected = false;
		self.anti8.selected = false;
		self.deviceQuality.msaaSampleCount = 4;
	else
		self.anti4.selected = true;
	end
end

function Lua_QualitySettingWindow:onanti8BoxClick(selected)
	if selected then
		self.anti2.selected = false;
		self.anti4.selected = false;
		self.anti0.selected = false;
		self.deviceQuality.msaaSampleCount = 8;
	else
		self.anti8.selected = true;
	end
end

function Lua_QualitySettingWindow:onmainlightshadow0BoxClick(selected)
	if selected then
		self.mainlightshadow1.selected = false;
		self.mainlightshadow2.selected = false;
		self.mainlightshadow3.selected = false;
		self.mainlightshadow4.selected = false;
		self.deviceQuality.supportsMainLightShadows = false;
	else
		self.mainlightshadow0.selected = true;
	end
end

function Lua_QualitySettingWindow:onmainlightshadow1BoxClick(selected)
	if selected then
		self.mainlightshadow0.selected = false;
		self.mainlightshadow2.selected = false;
		self.mainlightshadow3.selected = false;
		self.mainlightshadow4.selected = false;
		self.deviceQuality.supportsMainLightShadows = true;
		self.deviceQuality.mainLightShadowmapResolution = 256;
	else
		self.mainlightshadow1.selected = true;
	end
end

function Lua_QualitySettingWindow:onmainlightshadow2BoxClick(selected)
	if selected then
		self.mainlightshadow1.selected = false;
		self.mainlightshadow0.selected = false;
		self.mainlightshadow3.selected = false;
		self.mainlightshadow4.selected = false;
		self.deviceQuality.supportsMainLightShadows = true;
		self.deviceQuality.mainLightShadowmapResolution = 512;
	else
		self.mainlightshadow2.selected = true;
	end
end

function Lua_QualitySettingWindow:onmainlightshadow3BoxClick(selected)
	if selected then
		self.mainlightshadow1.selected = false;
		self.mainlightshadow2.selected = false;
		self.mainlightshadow0.selected = false;
		self.mainlightshadow4.selected = false;
		self.deviceQuality.supportsMainLightShadows = true;
		self.deviceQuality.mainLightShadowmapResolution = 1024;
	else
		self.mainlightshadow3.selected = true;
	end
end

function Lua_QualitySettingWindow:onmainlightshadow4BoxClick(selected)
	if selected then
		self.mainlightshadow1.selected = false;
		self.mainlightshadow2.selected = false;
		self.mainlightshadow3.selected = false;
		self.mainlightshadow0.selected = false;
		self.deviceQuality.supportsMainLightShadows = true;
		self.deviceQuality.mainLightShadowmapResolution = 2048;
	else
		self.mainlightshadow4.selected = true;
	end
end

function Lua_QualitySettingWindow:onaddilightshadow0BoxClick(selected)
	if selected then
		self.addilightshadow1.selected = false;
		self.addilightshadow2.selected = false;
		self.addilightshadow3.selected = false;
		self.addilightshadow4.selected = false;
		self.deviceQuality.supportsAdditionalLightShadows = false;
	else
		self.addilightshadow0.selected = true;
	end
end

function Lua_QualitySettingWindow:onaddilightshadow1BoxClick(selected)
	if selected then
		self.addilightshadow0.selected = false;
		self.addilightshadow2.selected = false;
		self.addilightshadow3.selected = false;
		self.addilightshadow4.selected = false;
		self.deviceQuality.supportsAdditionalLightShadows = true;
		self.deviceQuality.additionalLightsShadowmapResolution = 256;
	else
		self.addilightshadow1.selected = true;
	end
end

function Lua_QualitySettingWindow:onaddilightshadow2BoxClick(selected)
	if selected then
		self.addilightshadow1.selected = false;
		self.addilightshadow0.selected = false;
		self.addilightshadow3.selected = false;
		self.addilightshadow4.selected = false;
		self.deviceQuality.supportsAdditionalLightShadows = true;
		self.deviceQuality.additionalLightsShadowmapResolution = 512;
	else
		self.addilightshadow2.selected = true;
	end
end

function Lua_QualitySettingWindow:onaddilightshadow3BoxClick(selected)
	if selected then
		self.addilightshadow1.selected = false;
		self.addilightshadow2.selected = false;
		self.addilightshadow0.selected = false;
		self.addilightshadow4.selected = false;
		self.deviceQuality.supportsAdditionalLightShadows = true;
		self.deviceQuality.additionalLightsShadowmapResolution = 1024;
	else
		self.addilightshadow3.selected = true;
	end
end

function Lua_QualitySettingWindow:onaddilightshadow4BoxClick(selected)
	if selected then
		self.addilightshadow1.selected = false;
		self.addilightshadow2.selected = false;
		self.addilightshadow3.selected = false;
		self.addilightshadow0.selected = false;
		self.deviceQuality.supportsAdditionalLightShadows = true;
		self.deviceQuality.additionalLightsShadowmapResolution = 2048;
	else
		self.addilightshadow4.selected = true;
	end
end

function Lua_QualitySettingWindow:onpostBoxClick(selected)
	self.deviceQuality.bEnablePostProcessing = selected;
end

function Lua_QualitySettingWindow:onbone1BoxClick(selected)
	if selected then
		self.bone2.selected = false;
		self.bone4.selected = false;
		self.bonemax.selected = false;
		self.deviceQuality.skinWeights = 1;
	else
		self.bone1.selected = true;
	end
end

function Lua_QualitySettingWindow:onbone2BoxClick(selected)
	if selected then
		self.bone1.selected = false;
		self.bone4.selected = false;
		self.bonemax.selected = false;
		self.deviceQuality.skinWeights = 2;
	else
		self.bone2.selected = true;
	end
end

function Lua_QualitySettingWindow:onbone4BoxClick(selected)
	if selected then
		self.bone1.selected = false;
		self.bone2.selected = false;
		self.bonemax.selected = false;
		self.deviceQuality.skinWeights = 4;
	else
		self.bone4.selected = true;
	end
end

function Lua_QualitySettingWindow:onbonemaxBoxClick(selected)
	if selected then
		self.bone1.selected = false;
		self.bone2.selected = false;
		self.bone4.selected = false;
		self.deviceQuality.skinWeights = 255;
	else
		self.bonemax.selected = true;
	end
end

function Lua_QualitySettingWindow:onsoftshadowBoxClick(selected)
	self.deviceQuality.supportsSoftShadows = selected;
end