--红点树
Lua_RedPointTreeWindow = class("Lua_RedPointTreeWindow", Lua_Window);
function Lua_RedPointTreeWindow:ctor()
	self:superCall("ctor");
	self.blackAlpha = 0.1;
	self.showWinBg = true;
	self.showBlackMask = true;
	self.isFullSizeWin = true;
    self.isSingleShowWin = true;
	self.winBgPath = "/images/common/ui_common_bg_001.jpg";
	self.windowName = "Lua_RedPointTreeWindow";
end

function Lua_RedPointTreeWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.show_obj = UICreate.createGameObject(self.content, 0, 0, 0);

	self.mask_bg = UICreate.createUIAtlasImage(self.show_obj, "common_altas_1", "black_mask", 0, 0, 50000, 50000);
    self.mask_bg.alpha = 0.01;
    self.mask_bg.clickScale = false;
	self.mask_bg:addMousDownFuntion(self, self.onMouseDownHandle);
	self.mask_bg:addMouseUpFuntion(self, self.onMouseUpHandle);

	self.hideBtn = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_button_026", 62, 53, 0, 0);
	self.hideBtn.anchorValue = 6;
	self.hideBtn:addClickFuntion(self, self.onBackBtnClick);

	self:addLuaEvent("ON_PARENT_RED_POINT", self, self.onParentTreeClick);
	self:addLuaEvent("ON_PARENT_RED_POINT", self, self.showTree);
	self:startTimer();
	self:initRedPointInfo();
end

function Lua_RedPointTreeWindow:initRedPointInfo()
	self.rootArr = Array();--根节点
	self.parentDic = {};--父节点
	local parentId;
	local dic = DataCenter.redPointData._redPointVoDic; --getConfig("redPoint");
    for k, v in pairs(dic) do
        parentId = v.parentId;
        if parentId ~= nil then
            if self.parentDic[parentId] == nil then
        		self.parentDic[parentId] = Array();
        	end
            self.parentDic[parentId]:add(v);
	    else
	    	self.rootArr:add(v);
        end
    end
    self:showTree()
end

function Lua_RedPointTreeWindow:showTree()
	if self.showTreeArr == nil then
		self.showTreeArr = Array();
	end
    local item;
    local x = 0;
    for i=1, self.rootArr:getSize() do
    	item = self.showTreeArr[i];
    	if item == nil then
    		item = Lua_RedPointTreeContainerItem.new(self.show_obj);
	    	item:setIndex(i);
	    	item:setData({redPointId = self.rootArr[i].id, parentDic = self.parentDic});
	    	self.showTreeArr:add(item);
	    end
    	if i > 1 then
    		item:setLocation(x, 0, 0);
    	else
    		item:setLocation(0, 0, 0);
    	end
    	x = x + item.wide;
    end
end

function Lua_RedPointTreeWindow:onParentTreeClick(data)
	local index = data.index;
	local redPointId = data.redPointId;
	if self.showTreeArr[index] ~= nil then
		self.showTreeArr[index]:updateParentTree(redPointId);
	end
end


function Lua_RedPointTreeWindow:onScreenResize()
	self:superCall("onScreenResize");
end

function Lua_RedPointTreeWindow:onMouseDownHandle(go)
	self.canDrag = true;
	self.startMouseX = CommonUtil.mousePositionX;
	self.startMouseY = CommonUtil.mousePositionY;
end

function Lua_RedPointTreeWindow:onMouseUpHandle(go)
	self.canDrag = false;
end

function Lua_RedPointTreeWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_RedPointTreeWindow", 0.01, self, self.onTimer, nil, -1);
	end
end

function Lua_RedPointTreeWindow:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_RedPointTreeWindow:onTimer()
	self:onDebugDrag()
end

function Lua_RedPointTreeWindow:onDebugDrag()
	if self.canDrag ~= true then
		return
	end

    local dx = CommonUtil.mousePositionX - self.startMouseX;
    local dy = CommonUtil.mousePositionY - self.startMouseY;
    self.startMouseX = CommonUtil.mousePositionX;
    self.startMouseY = CommonUtil.mousePositionY;

    local vec = self.show_obj.transform.localPosition;
    local targetX = vec.x + dx;
    -- local vw = UnityEngine.Screen.width / GlobalVar.scaleRatio;
    -- if targetX < -(vw - self.w)/2 or targetX > (vw - self.w)/2 then
    -- 	return;
    -- end

    local targetY = vec.y + dy;
    -- local vh = UnityEngine.Screen.height / GlobalVar.scaleRatio;
    -- if targetY < -(vh - self.h)/2 or targetY > (vh - self.h)/2 then
    -- 	return;
    -- end

    LuaUtil.setObjPos(self.show_obj, targetX, targetY, vec.z);
end

function Lua_RedPointTreeWindow:onBackBtnClick(go)
	self:hide();
end

function Lua_RedPointTreeWindow:dispose()
	if self.showTreeArr ~= nil then
		self.showTreeArr:dispose();
		self.showTreeArr:clear();
		self.showTreeArr = nil;
	end
	self.rootArr = nil;
	self.parentDic = nil;
	self:endTimer();
	self:superCall("dispose");
end































Lua_RedPointTreeContainerItem = class("Lua_RedPointTreeContainerItem", Lua_DisplayObject);
function Lua_RedPointTreeContainerItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_RedPointTreeContainerItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_RedPointTreeContainerItem:setIndex(index)
	self.index = index;
end

function Lua_RedPointTreeContainerItem:setData(data)
	if self.id == data.redPointId then
		return;
	end
	self.data = data;
	self.id = data.redPointId;
	self.parentDic = data.parentDic;
	
    self.layer = 0;--层
    self.treeItemDic = {};
    self.layerPosDic = {};
    self:drawTree(self.content, self.id, 1, 1, 540, false);
end

--获取每层父节点的末端节点的个数
function Lua_RedPointTreeContainerItem:getNodeNum(id)
	if self.node_num == nil then
		self.node_num = 0;
	end
	local arr = self.parentDic[id];
	if arr ~= nil and arr:getSize() > 0 then
		for i=1, arr:getSize() do
			self:getNodeNum(arr[i].id);
		end
	else
		self.node_num = self.node_num + 1;
	end

	return self.node_num;
end

function Lua_RedPointTreeContainerItem:drawTree(content, id, layer, index, posY, bParent)
    local item = self.treeItemDic[id];
    if item == nil then
    	item = Lua_RedPointTreeItem.new(content);
    	item.contentName = "Lua_RedPointTreeItem"..layer.."_"..index;
    	self.treeItemDic[id] = item;
    end

    item:setData(id);
    item:setParent(bParent);
    item:setRootIndex(self.index);

	local posX;
	if layer > 1 then
		posX = 270;
	else
		posX = -240+(layer-1)*270;
	end
    item:setLocation(posX, posY, 0)

    if self.depthDic == nil then
		self.depthDic = {};
	end
	if self.depthDic[layer] == nil then
		self.depthDic[layer] = {};
	end
	if self.depthDic[layer][index] == nil then
		self.depthDic[layer][index] = {};
	end
	self.depthDic[layer][index] = id;

	if self.layer < layer then
		self.layer = layer;
	end

    if self.parentDic[id] ~= nil then
    	layer = layer + 1;
    	self.layerPosDic[layer] = 0;
    	
    	local arr = self.parentDic[id];
    	local len = arr:getSize();

		local node_num = 0;
		local tag_index = 0;
    	for i=1,len do
    		if i > 1 then
				local id = self.depthDic[layer][i-1];
				self.node_num = nil;
				node_num = self:getNodeNum(id);
				if node_num <= 1 then
					node_num =  i - tag_index;
				end
			end
 			tag_index = i;
			local posY = self.layerPosDic[layer] - node_num * 160;
			self.layerPosDic[layer] = posY;
    		self:drawTree(item.content, arr[i].id, layer, i, posY, true);
    	end
    	item:setNode(len, self.layerPosDic[layer]);
    else
    	item:setNode(0,0);
    end
end

--折叠展开
function Lua_RedPointTreeContainerItem:updateParentTree(id)
	if self.id == id then
		OperateAlert.show("这是根节点")
		return
	end
	if self.parentDic[id] == nil then
		OperateAlert.show("没有子节点")
		return
	end

	if self.enableNodeDic == nil then
		self.enableNodeDic = {};
	end

	if self.enableNodeDic[id] == nil then
		self.enableNodeDic[id] = Array();
	end

	local arr;
	local bEnable = false;
	local len = self.enableNodeDic[id]:getSize();
	if len == 0 then
	    bEnable = false;
	    arr = self.parentDic[id];
	else
		bEnable = true;
		arr = self.enableNodeDic[id];
	end

	local item;
    for i=1,arr:getSize() do
    	item = self.treeItemDic[arr[i].id];
	    item:setEnable(bEnable);
	    if bEnable == false then
	    	self.enableNodeDic[id]:add(arr[i]);
	    else
	    	self.parentDic[id]:add(arr[i]);
	    end
    end
    arr:clear();
    self.layer = 0;
    self:updateTreeLocation(self.id, 1, 1, 540);
end

function Lua_RedPointTreeContainerItem:clearId(id)

end
function Lua_RedPointTreeContainerItem:updateTreeLocation(id, layer, index, posY)
    local item = self.treeItemDic[id];
	local posX;
	if layer > 1 then
		posX = 270;
	else
		posX = -240+(layer-1)*270;
	end
    item:setLocation(posX, posY, 0)
    
	if self.layer < layer then
		self.layer = layer;
	end

    if self.parentDic[id] ~= nil then
    	layer = layer + 1;
    	self.layerPosDic[layer] = 0;
    	
    	local arr = self.parentDic[id];
    	local len = arr:getSize();
		local node_num = 0;
		local tag_index = 0;
    	for i=1,len do
    		if i > 1 then
				local id = self.depthDic[layer][i-1];
				self.node_num = nil;
				node_num = self:getNodeNum(id);
				if node_num <= 1 then
					node_num =  i - tag_index;
				end
			end
 			tag_index = i;
			local posY = self.layerPosDic[layer] - node_num * 160;
			self.layerPosDic[layer] = posY;
    		self:updateTreeLocation(arr[i].id, layer, i, posY);
    	end
    	item:setNode(len, self.layerPosDic[layer], false);
    else
    	item:setNode(0, 0, false);
    end
end

function Lua_RedPointTreeContainerItem.Get:wide()
	return self.layer*234 + self.layer*45;
end

function Lua_RedPointTreeContainerItem:dispose()
	if self.treeItemDic ~= nil then
    	for k,v in pairs(self.treeItemDic) do
    		v:dispose();
    		v = nil;
    	end
    end
    self.treeItemDic = nil;
	self.layerPosDic = nil;
	self.enableNodeDic = nil;
	self:superCall("dispose");
end































Lua_RedPointTreeItem = class("Lua_RedPointTreeItem", Lua_DisplayObject);
function Lua_RedPointTreeItem:ctor(p)
    self:superCall("ctor", p);
end

function Lua_RedPointTreeItem:buildShowItem()
    self:superCall("buildShowItem");

    self.bg = UICreate.createUIAtlasImage(self.content, "hero_heat_atlas", "xui_rdb_toggle_1_b", 0, 0, 234, 160);
    self.bg:addClickFuntion(self, self.onBgBtnClick);

    self.rarent_line = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_line_004", -123, 0, 30, 4);
	self.node_line1 = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_line_004", 119, 0, 18, 4);

	self.node_line2 = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_line_004", 130, 2, 4, 4);
    self.node_line2.pivot = UIUtils.Pivot.Top;

    self.id_txt = UICreate.createLabel(self.content, nil, -100, 66, 200, 52, 20);
    self.id_txt.pivot = UIUtils.Pivot.TopLeft;
    self.id_txt.alignmentValue = 0;

    self.name_txt = UICreate.createLabel(self.content, nil, -100, 15, 200, 52, 20);
    self.name_txt.pivot = UIUtils.Pivot.TopLeft;
    self.name_txt.alignmentValue = 0;

    self.num_txt = UICreate.createLabel(self.content, nil, -100, -40, 125, 52, 20);
    self.num_txt.pivot = UIUtils.Pivot.TopLeft;
    self.num_txt.alignmentValue = 0;
end

function Lua_RedPointTreeItem:setData(redPointId)
	self.redPointId = redPointId;
	self.id_txt.text = Lua_ColorDefine.getColorStr("15EE00",redPointId);
	local data = getConfig("redPoint", redPointId);
	self.name_txt.text = data == nil and "运营活动id: " .. redPointId or data.name;

	local redDotState = DataCenter.redPointData:getRedPointStateById(redPointId);
    self:showRedPoint(redDotState);
end

--子节点数量
function Lua_RedPointTreeItem:setNode(num, posY, bool)
	-- print("子节点数量  == ",num)
	self.node_line1:setEnable(num > 0);
	self.node_line2:setEnable(num > 0);
	local height = Mathf.Abs(posY) + 4;
	if num <= 1 then
		height = 4;
	end
	if bool ~= false then
		self.num_txt.text = "节点数："..num.."个";
	end
	self.node_line2:SetDimensions(4, height);
end

function Lua_RedPointTreeItem:setLine(bool)
	self.node_line2:setEnable(bool);
	self.node_line1:setEnable(bool);
end

--是否有父节点
function Lua_RedPointTreeItem:setParent(bool)
	self.rarent_line:setEnable(bool);
end

--设置所在根节点索引
function Lua_RedPointTreeItem:setRootIndex(index)
	self.rootIndex = index;
end

function Lua_RedPointTreeItem:onBgBtnClick()
    Lua_MsgUtil.callFunc("ON_PARENT_RED_POINT", {index = self.rootIndex, redPointId = self.redPointId});
end

function Lua_RedPointTreeItem:showRedPoint(bShow)
    if bShow then
        if self.redPointIcon == nil then
            self.redPointIcon = Lua_RedPointIcon.new(self.content);
            self.redPointIcon:setLocation(96, -58);
            self.redPointIcon:createRedPointEff();
        end
        self.redPointIcon:updateRedPointShow(true);
    else
        if self.redPointIcon ~= nil then
            self.redPointIcon:updateRedPointShow(false);
        end
    end
end

function Lua_RedPointTreeItem:dispose()
	if self.redPointIcon ~= nil then
		self.redPointIcon:dispose();
		self.redPointIcon = nil;
	end
	self:superCall("dispose");
end