Lua_ScreenAdapterChangeWindow = class("Lua_ScreenAdapterChangeWindow", Lua_Window);
function Lua_ScreenAdapterChangeWindow:ctor()
	self:superCall("ctor");
	
	self.windowName = "Lua_ScreenAdapterChangeWindow";
	self.skinName = "ScreenAdapterChangeWindow_skin";
end

function Lua_ScreenAdapterChangeWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.defaultAspect = MainWinDefine.DEFAULT_WIDTH / MainWinDefine.DEFAULT_HEIGHT;
	self.cam = GlobalVar.mainCamera;
	if self.cam.orthographic == true then
		self.inputFieldView.text = self.cam.orthographicSize;
	else
		self.inputFieldView.text = self.cam.fieldOfView;
	end

	self:addLuaEvent("SCREEN_RESIZE_LUA", self, self.onScreenResize);
	self.btnComfirm:addClickFuntion(self, self.onBtnConfirmClick);
	self:update();
end

function Lua_ScreenAdapterChangeWindow:onScreenResize()
	Lua_CommonUtil.delayCall(0.5, self, self.onUpdateSize)
end

function Lua_ScreenAdapterChangeWindow:onUpdateSize()
	if self.cam.orthographic == true then
		self.inputFieldView.text = self.cam.orthographicSize;
	else
		self.inputFieldView.text = self.cam.fieldOfView;
	end
	self:update();
end

function Lua_ScreenAdapterChangeWindow:update()
	if self.cam == nil then
		return;
	end

	local sceneId = Scene3DManager.instance.curShowSceneId;
	local cfg = Lua_SceneConfigData.getSceneConfig(sceneId);
	if cfg == nil then
		return;
	end

	local size = tonumber(tostring(self.inputFieldView.text));
	if self.cam.orthographic == true then
		local aspect = self.cam.aspect;
		if aspect > self.defaultAspect then
			aspect = self.defaultAspect;
		end

		local adapterRate = self.defaultAspect / aspect;
		local defaultSize = size / adapterRate;
		self.outFieldView.text = tostring(defaultSize);
	else
		local manualHeight = MainWinDefine.DEFAULT_HEIGHT;
		local w = UnityEngine.Screen.width;
		local h = UnityEngine.Screen.height;
	    if w / h < self.defaultAspect then
	        manualHeight = MainWinDefine.DEFAULT_WIDTH / w * h;
	    end
	    local adapterRate = manualHeight / MainWinDefine.DEFAULT_HEIGHT;
	    local defaultFieldOfView = size / adapterRate
	    self.outFieldView.text = tostring(defaultFieldOfView);
	end
end

function Lua_ScreenAdapterChangeWindow:dispose()
	self:superCall("dispose");
	Lua_CommonUtil.removeTimer(self, self.onUpdateSize);
end

function Lua_ScreenAdapterChangeWindow:onBtnConfirmClick(go)
	self:update();
end