Lua_TestGMWindow = class("Lua_TestGMWindow", Lua_Window)
function Lua_TestGMWindow:ctor()
	self:superCall("ctor");

	self.w = 0;
	self.h = 0;
	self.layer = MainWinDefine.MAX_TOP_LAYER;
	self.windowName = "Lua_TestGMWindow";
	self.skinName = "GMWindow_skin";
	self.showBlackMask = false;
	self.isClickClose = false;
end

function Lua_TestGMWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.showArr = Array();
    self.hideArr = Array();
	self.searchObject:SetActive(true);
	self.resultObject:SetActive(false);
	self:addLuaEvent("SELECT_TEST_GM", self, self.onGMSelected);

	self.itemList = Lua_DragList.new(self.searchObject, 650, 800, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_GMItem, 650, 60, 1);
	self.itemList:setLocation(0, -50, 0);

	self.winBg.clickScale = false;
	self.winBg:addMousDownFuntion(self, self.onMouseDownHandle);
	self.winBg:addMouseUpFuntion(self, self.onMouseUpHandle);

	self.searchInput.defaultText = "输入关键字进行筛选";
	self.searchInput:onChange(self, self.onSearch);
	self.btnSend:addClickFuntion(self, self.onBtnSendClick);
	self.btnHide:addClickFuntion(self, self.onBtnHideClick);

	local config = getConfig("gm_test");
	self.gmArr = Array()
	for _, v in pairs(config) do
		self.gmArr:add(v)
	end
	quickSort(self.gmArr, "index", true)
	self:setGMInfo();
end

function Lua_TestGMWindow:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
    if self.showArr then
        self.showArr:dispose();
        self.showArr:clear();
        self.showArr = nil;
    end
    if self.hideArr then
        self.hideArr:dispose();
        self.hideArr:clear();
        self.hideArr = nil;
    end
    if self.gmArr then
    	self.gmArr:clear()
    	self.gmArr = nil
    end
	self:superCall("dispose");
end

function Lua_TestGMWindow:onMouseDownHandle(go)
	self:onPress(go, true);
end

function Lua_TestGMWindow:onMouseUpHandle(go)
	self:onPress(go, false);
end

function Lua_TestGMWindow:onPress(go, state)
    if state == true then
    	self.clickTime = getTime();
        if self.bDragClick == nil or self.bDragClick == false then
            self.bDragClick = true;
            self.startMouseX = CommonUtil.mousePositionX;
            self.startMouseY = CommonUtil.mousePositionY;
            Lua_CommonUtil.addTimer("Lua_TestGMWindow", 0.01, self, self.onDragFrame);
        end   
    else
        if self.bDragClick ~= nil and self.bDragClick == true then
            self.bDragClick = false;
            Lua_CommonUtil.removeTimer(self, self.onDragFrame);
        end
    end
end

function Lua_TestGMWindow:onDragFrame()
	local dx = CommonUtil.mousePositionX - self.startMouseX;
	local dy = CommonUtil.mousePositionY - self.startMouseY;
	self.startMouseX = CommonUtil.mousePositionX;
	self.startMouseY = CommonUtil.mousePositionY;

	local vec = self.content.transform.localPosition;
	local targetX = vec.x + dx;
	local vw = UnityEngine.Screen.width / GlobalVar.scaleRatio;
	if targetX < -(vw - self.w) / 2 or targetX > (vw - self.w) / 2 then
		return;
	end

	local targetY = vec.y + dy;
	local vh = UnityEngine.Screen.height / GlobalVar.scaleRatio;
	if targetY < -(vh - self.h) / 2 or targetY > (vh - self.h) / 2 then
		return;
	end

	LuaUtil.setObjPos(self.content, targetX, targetY, vec.z);
end

function Lua_TestGMWindow:onSearch()
	self:setGMInfo(self.searchInput.text);
end

function Lua_TestGMWindow:onBtnSendClick(go)
	local cmd = ProtoPublic_pb.Proto10111999();
	local str = self.cmd.text;
	cmd.cmd_name = str;

	local item = self.showArr[1];
	if item ~= nil then
		str = item.paramInput.text;
		if not strIsNullOrEmpty(str) then
			cmd.param1 = tonumber(str);
		end
	end

	item = self.showArr[2];
	if item ~= nil then
		str = item.paramInput.text;
		if not strIsNullOrEmpty(str) then
			cmd.param2 = tonumber(str);
		end
	end

	item = self.showArr[3];
	if item ~= nil then
		str = item.paramInput.text;
		if not strIsNullOrEmpty(str) then
			cmd.param3 = tonumber(str);
		end
	end

	item = self.showArr[4];
	if item ~= nil then
		str = item.paramInput.text;
		if not strIsNullOrEmpty(str) then
			cmd.param4 = tonumber(str);
		end
	end
	
	sendMsg(10111999, cmd);
end

function Lua_TestGMWindow:onBtnHideClick(go)
	self.resultObject:SetActive(false);
	self.searchObject:SetActive(true);
end

function Lua_TestGMWindow:setGMInfo(str)
	if strIsNullOrEmpty(str) then
		self.itemList:setArrayData(self.gmArr);
	else
		local arr = Array();
		for i = 1, self.gmArr:getSize() do
			if string.find(self.gmArr[i].name, str) ~= nil or string.find(self.gmArr[i].des, str) then
				arr:add(self.gmArr[i]);
			end
		end
		self.itemList:setArrayData(arr);
	end
	self.itemList:moveToIndex(1, true);
end

function Lua_TestGMWindow:onGMSelected(data)
	self.searchObject:SetActive(false);
	self.resultObject:SetActive(true);
	self.name.text = data.name;
	self.des.text = data.des;
	self.cmd.text = data.cmd_name;

	self:returntItem();
	local item;
	local startY = 180;
	local index = 0;
	local spaceY = -60;
	if data.param1_des ~= nil then
		item = self:createItem();
		item:setLocation(0, startY + index * spaceY, 0);
		item:setData(data.param1_des.."：", data.param1);
		if data.index == 3 then
			item.key = "item";
		elseif data.index == 11 then
			item.key = "hero";
		end
		index = index + 1;
	end

	if data.param2_des ~= nil then
		item = self:createItem();
		item:setLocation(0, startY + index * spaceY, 0);
		item:setData(data.param2_des.."：", data.param2);
		index = index + 1;
	end

	if data.param3_des ~= nil then
		item = self:createItem();
		item:setLocation(0, startY + index * spaceY, 0);
		item:setData(data.param3_des.."：", data.param3);
		index = index + 1;
	end

	if data.param4_des ~= nil then
		item = self:createItem();
		item:setLocation(0, startY + index * spaceY, 0);
		item:setData(data.param4_des.."：", data.param4);
	end
end

function Lua_TestGMWindow:createItem()
    local len = self.hideArr:getSize();
    local item = nil;
    if len > 0 then
        item = self.hideArr:remove();
        item:setEnable(true);
    end

    if item == nil then
        item = Lua_GMInputItem.new(self.resultObject);
    end
    self.showArr:add(item);
    return item;
end

function Lua_TestGMWindow:returntItem()
    local len = self.showArr:getSize();
    local item;
    while len > 0 do
        item = self.showArr:remove(len);
        item.key = nil;
        item:setEnable(false);
        self.hideArr:add(item)
        len = len - 1;
    end
end




















Lua_GMItem = class("Lua_GMItem", Lua_ListCell);
function Lua_GMItem:ctor(p)
	self:superCall("ctor", p, "GMItem_skin");
end

function Lua_GMItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_GMItem:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_GMItem:setData(data)
	self.data = data;
	self.name.text = data.name;
	self.des.text = data.des;
end

function Lua_GMItem:onPressClick()
	Lua_MsgUtil.callFunc("SELECT_TEST_GM", self.data);
end



















Lua_GMInputItem = class("Lua_GMInputItem", Lua_DisplayObject);
function Lua_GMInputItem:ctor(p)
	self:superCall("ctor", p, "GMInputItem_skin");
end

function Lua_GMInputItem:buildShowItem()
	self:superCall("buildShowItem");
	self.inputBg.clickScale = false;
	self.paramInput.contentTypeValue = 2;
end

function Lua_GMInputItem:dispose()
	self:superCall("dispose");
end

function Lua_GMInputItem:setData(des, defaultVal)
	self.desText.text = des;
	self.paramInput.text = defaultVal;
	if strIsNullOrEmpty(defaultVal) then
		self.paramInput.inputMouseEnable = true;
	else
		self.paramInput.inputMouseEnable = false;
	end
end

function Lua_GMInputItem.Set:key(value)
	self._key = value;

	if value ~= nil then
		self.inputBg.mouseEnable = true;
		self.inputBg:addClickFuntion(self, self.onBgClick);
		self.paramInput.inputMouseEnable = false;
	else
		self.inputBg.mouseEnable = false;
		self.inputBg:removeClickFuntion(self, self.onBgClick);
		self.paramInput.inputMouseEnable = true;
	end
end

function Lua_GMInputItem.Get:key()
	return self._key;
end

function Lua_GMInputItem:onBgClick(go)
	Lua_WindowUtil.openWin("Lua_TestItemSelectWindow", Lua_WinParam.ACTION_OPEN, self.key);
	Lua_MsgUtil.addEventListener("TEST_ITEM_SELECT", self, self.onItemSelected);
end

function Lua_GMInputItem:onItemSelected(data)
	if data ~= nil then
		if self.key == "item" then
			self.paramInput.text = tostring(data.id);
		elseif self.key == "hero" then
			self.paramInput.text = tostring(data.hero_id);
		end
	end
	Lua_MsgUtil.removeEventListener("TEST_ITEM_SELECT", self, self.onItemSelected);
end