checkRequire("Lua_FightDebugSetItem")
Lua_FightDebugEditWindow = class("Lua_FightDebugEditWindow", Lua_Window)
function Lua_FightDebugEditWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_FightDebugEditWindow"
	self.skinName = "FightDebugEditWindow_skin"
end

function Lua_FightDebugEditWindow:buildShowItem()
	self:superCall("buildShowItem")
	self.attackList = Array()
	self.defendList = Array()

	self.plotInput.contentTypeValue = 2;
	self.btnStart:addClickFuntion(self, self.onStartClick)
	
	self.attackContainer = Lua_DragList.new(self.content, 640, 975, Lua_AxisDefine.Vertical)
	self.attackContainer.movementTypeValue = 2
	self.attackContainer.inertia = false
	self.attackContainer:setLocation(0, 65)
	self.attackContainer:setListCell(Lua_FightDebugEditItem, 640, 850, 1)
	self.attackContainer:setCellSpacing(0, 10)
	self.attackContainer:setEnable(false)

	self.defendContainer = Lua_DragList.new(self.content, 640, 975, Lua_AxisDefine.Vertical)
	self.defendContainer.movementTypeValue = 2
	self.defendContainer.inertia = false
	self.defendContainer:setLocation(0, 65)
	self.defendContainer:setListCell(Lua_FightDebugEditItem, 640, 850, 1)
	self.defendContainer:setCellSpacing(0, 10)
	self.defendContainer:setEnable(false)

	self.btnInfo = Array();
	self.btnInfo:add({ textStr = "攻方" })
	self.btnInfo:add({ textStr = "守方" })

	self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal)
	self.btnList:setLocation(0, -485, 0)
	self.btnList:setButtonItem(184, 62)
	self.btnList:setClickCallBack(self, self.onButtonClick)
	self.btnList:setData(self.btnInfo)
	self.btnList:setSelected(1)

	self:addAttacker()
	self:addDefender()
	self:addLuaEvent("FIHGTPLAY_ATTACKER_ADD", self, self.addAttacker)
	self:addLuaEvent("FIHGTPLAY_ATTACKER_REMOVE", self, self.removeAttacker)
	self:addLuaEvent("FIHGTPLAY_DEFENDER_ADD", self, self.addDefender)
	self:addLuaEvent("FIHGTPLAY_DEFENDER_REMOVE", self, self.removeDefender)
end

function Lua_FightDebugEditWindow:dispose()
	if self.attackContainer then
		self.attackContainer:dispose()
		self.attackContainer = nil
	end
	if self.attackList then
		self.attackList:dispose()
		self.attackList:clear()
		self.attackList = nil
	end
	if self.defendContainer then
		self.defendContainer:dispose()
		self.defendContainer = nil
	end
	if self.defendList then
		self.defendList:dispose()
		self.defendList:clear()
		self.defendList = nil
	end
	if self.btnList then
		self.btnList:dispose()
		self.btnList = nil
	end
	if self.btnInfo then
		self.btnInfo:dispose()
		self.btnInfo:clear()
		self.btnInfo = nil
	end
	self:superCall("dispose")
end

function Lua_FightDebugEditWindow:onButtonClick(index)
	self.attackContainer:setEnable(index == 1)
	self.defendContainer:setEnable(index == 2)
end

function Lua_FightDebugEditWindow:getStandIdx(ownType)
	local existDic = {}
	if ownType == Lua_FightDefine.FIGHT_ATTACKER then
		for i = 1, self.attackList:getSize() do
			existDic[self.attackList[i].position] = 1
		end
	else
		for i = 1, self.defendList:getSize() do
			existDic[self.defendList[i].position] = 1
		end
	end
	for i = 1, 10 do
		if existDic[i] == nil then
			return i
		end
	end
	return 0
end

function Lua_FightDebugEditWindow:addAttacker()
	local position = self:getStandIdx(Lua_FightDefine.FIGHT_ATTACKER)
	local len = self.attackList:getSize()
	if position == nil or len >= 11 then
		OperateAlert.show("上阵数量已满")
		return
	end

	self.attackList:add(Lua_FightDebugEditVo.new(len + 1, Lua_FightDefine.FIGHT_ATTACKER, position))
	self.attackContainer:setArrayData(self.attackList)
	self.attackContainer:moveToIndex(len + 1, true)
end

function Lua_FightDebugEditWindow:removeAttacker(index)
	if self.attackList:getSize() <= 1 then
		OperateAlert.show("上阵数量必须有1个")
		return
	end

	self.attackList:remove(index)
	self.attackContainer:setArrayData(self.attackList)
end

function Lua_FightDebugEditWindow:addDefender()
	local position = self:getStandIdx(Lua_FightDefine.FIGHT_DEFENDER)
	local len = self.defendList:getSize()
	if position == nil or len >= 11 then
		OperateAlert.show("上阵数量已满")
		return
	end

	self.defendList:add(Lua_FightDebugEditVo.new(len + 1, Lua_FightDefine.FIGHT_DEFENDER, position))
	self.defendContainer:setArrayData(self.defendList)
	self.defendContainer:moveToIndex(len + 1, true)
end

function Lua_FightDebugEditWindow:removeDefender(index)
	if self.defendList:getSize() <= 1 then
		OperateAlert.show("上阵数量必须有1个")
		return
	end
	
	self.defendList:remove(index)
	self.defendContainer:setArrayData(self.defendList)
end

function Lua_FightDebugEditWindow:onStartClick(go)
	if self.curTime and getTime() - self.curTime < 3 then
		OperateAlert.show("点击太快了，等等服务端")
		return
	end
	self.curTime = getTime()

	local len = self.attackList:getSize()
	if len < 1 then
		OperateAlert.show("攻方上阵数量必须有1个")
		return
	end

	local arr = DataCenter.attributesUtil:getDebugSetProps()
	local attrLen = arr:getSize()

	local data
	local posDic = {}
	local cmd = ProtoPublic_pb.Proto10102004()
	for i = 1, len do 
		data = self.attackList[i]
		if posDic[data.position] then
			OperateAlert.show("进攻方"..i.."和进攻方"..posDic[data.position].."站位分配重复")
			return
		end
		posDic[data.position] = i

		if data.position == 0 then
			cmd.att_role.sort_id = data.sort_id
			cmd.att_role.level = data.level
			cmd.att_role.position = data.position

			for j = 1, #data.skill_list do
				local skillId = data.skill_list[j]
				if skillId ~= 0 then
					cmd.att_role.skill_list:append(skillId)
				end
			end

			for j = 1, attrLen do
				local vo = arr[j]
				local val = data.prop[vo.id]
				local propObj = getProtoMsg("ProtoProp")
				propObj.name = vo.id
				if vo.isPercent == 1 then
					propObj.value = val / 100
				else
					propObj.value = val
				end 
				cmd.att_role.prop:addToList(propObj)
			end
		else
			local protoObj = getProtoMsg("ProtoFightDebugInfo")
			protoObj.sort_id = data.sort_id
			protoObj.level = data.level
			protoObj.position = data.position

			for j = 1, #data.skill_list do
				local skillId = data.skill_list[j]
				if skillId ~= 0 then
					protoObj.skill_list:append(skillId)
				end
			end

			for j = 1, attrLen do
				local vo = arr[j]
				local val = data.prop[vo.id]
				local propObj = getProtoMsg("ProtoProp")
				propObj.name = vo.id
				if vo.isPercent == 1 then
					propObj.value = val / 100
				else
					propObj.value = val
				end 
				protoObj.prop:addToList(propObj)
			end

			cmd.attacker:addToList(protoObj)
		end
	end

	len = self.defendList:getSize()
	if len < 1 then
		OperateAlert.show("守方上阵数量必须有1个")
		return
	end

	posDic = {}
	for i = 1, len do 
		data = self.defendList[i]
		if posDic[data.position] then
			OperateAlert.show("进攻方"..i.."和进攻方"..posDic[data.position].."站位分配重复")
			return
		end
		posDic[data.position] = i

		if data.position == 0 then
			cmd.def_role.sort_id = data.sort_id
			cmd.def_role.level = data.level
			cmd.def_role.position = data.position

			for j = 1, #data.skill_list do
				local skillId = data.skill_list[j]
				if skillId ~= 0 then
					cmd.def_role.skill_list:append(skillId)
				end
			end

			for j = 1, attrLen do
				local vo = arr[j]
				local val = data.prop[vo.id]
				local propObj = getProtoMsg("ProtoProp")
				propObj.name = vo.id
				if vo.isPercent == 1 then
					propObj.value = val / 100
				else
					propObj.value = val
				end 
				cmd.def_role.prop:addToList(propObj)
			end
		else
			local protoObj = getProtoMsg("ProtoFightDebugInfo")
			protoObj.sort_id = data.sort_id
			protoObj.level = data.level
			protoObj.position = data.position

			for j = 1, #data.skill_list do
				local skillId = data.skill_list[j]
				if skillId ~= 0 then
					protoObj.skill_list:append(skillId)
				end
			end

			for j = 1, attrLen do
				local vo = arr[j]
				local val = data.prop[vo.id]
				local propObj = getProtoMsg("ProtoProp")
				propObj.name = vo.id
				if vo.isPercent == 1 then
					propObj.value = val / 100
				else
					propObj.value = val
				end 
				protoObj.prop:addToList(propObj)
			end

			cmd.defender:addToList(protoObj)
		end
	end

	if strIsNullOrEmpty(self.plotInput.text) then
		cmd.plot_id = 0
	else
		cmd.plot_id = tonumber(self.plotInput.text)
	end
	sendMsg(10102004, cmd)
end




















Lua_FightDebugEditItem = class("Lua_FightDebugEditItem", Lua_ListCell)
function Lua_FightDebugEditItem:ctor(p)
	self:superCall("ctor", p, "FightDebugEditItem_skin")
end

function Lua_FightDebugEditItem:buildShowItem()
	self:superCall("buildShowItem")
	self.cellList = Array()

	self.btnDel:addClickFuntion(self, self.onDelClick)
	self.btnAdd:addClickFuntion(self, self.onAddClick)
end

function Lua_FightDebugEditItem:dispose()
	if self.cellList then
		self.cellList:dispose()
		self.cellList:clear()
		self.cellList = nil
	end
	self.data = nil
	self:superCall("dispose")
end

function Lua_FightDebugEditItem:setData(data)
	self.data = data
	self:init()
	if data.ownType == Lua_FightDefine.FIGHT_ATTACKER then
		self.descText.text = "攻方"
	else
		self.descText.text = "守方"
	end
end

function Lua_FightDebugEditItem:init()
	if self.cellList then
		for i = 1, self.cellList:getSize() do
			self.cellList[i]:setCallBack(nil, nil)
		end
	end

	local index = 1
	local cell = self.cellList[index]
	if cell == nil then
		cell = Lua_FightDebugSetItem.new(self.content)
		self.cellList:add(cell)
	end
	cell:setLocation(-100, 340, 0)
	cell:setData(self.data)
	cell:setKey("sort_id")
	if self.data.position == 0 then
		cell:setName("神器")
	end
	self.sortCell = cell

	index = index + 1
	cell = self.cellList[index]
	if cell == nil then
		cell = Lua_FightDebugSetItem.new(self.content)
		self.cellList:add(cell)
	end
	cell:setLocation(200, 340, 0)
	cell:setData(self.data)
	cell:setKey("position")
	cell:setCallBack(self, self.onPosChange)

	index = index + 1
	cell = self.cellList[index]
	if cell == nil then
		cell = Lua_FightDebugSetItem.new(self.content)
		self.cellList:add(cell)
	end
	cell:setLocation(-100, 290, 0)
	cell:setData(self.data)
	cell:setKey("level")

	local step = 1
	local offsetY = 290
	local arr = DataCenter.attributesUtil:getDebugSetProps()
	local len = arr:getSize()
	for i = 1, len do
		index = index + 1
		cell = self.cellList[index]
		if cell == nil then
			cell = Lua_FightDebugSetItem.new(self.content)
			self.cellList:add(cell)
		end
		if step == 1 then
			if i % 2 == 0 then
				cell:setLocation(-100, offsetY, 0)
			else
				cell:setLocation(200, offsetY, 0)
				offsetY = offsetY - 45
			end
		else
			if i % 2 == 0 then
				cell:setLocation(200, offsetY, 0)
				offsetY = offsetY - 45
			else
				cell:setLocation(-100, offsetY, 0)
			end
		end
		cell:setData(self.data)
		cell:setKey("attr", arr[i].id)
		cell:setName(arr[i].show_name)
	end

	step = step - (len % 2)
	for i = 1, 5 do
		index = index + 1
		cell = self.cellList[index]
		if cell == nil then
			cell = Lua_FightDebugSetItem.new(self.content)
			self.cellList:add(cell)
		end
		if step == 1 then
			if i % 2 == 0 then
				cell:setLocation(-100, offsetY, 0)
			else
				cell:setLocation(200, offsetY, 0)
				offsetY = offsetY - 45
			end
		else
			if i % 2 == 0 then
				cell:setLocation(200, offsetY, 0)
				offsetY = offsetY - 45
			else
				cell:setLocation(-100, offsetY, 0)
			end
		end
		cell:setData(self.data)
		cell:setKey("skill", i)
	end
end

function Lua_FightDebugEditItem:onPosChange()
	if self.data.position == 0 then
		self.sortCell:setName("神器")
	else
		self.sortCell:setName("英雄")
	end
	self.sortCell:updateShowInfo()
end

function Lua_FightDebugEditItem:onDelClick(go)
	if self.data.ownType == Lua_FightDefine.FIGHT_ATTACKER then
		Lua_MsgUtil.callFunc("FIHGTPLAY_ATTACKER_REMOVE", self.data.index)
	else
		Lua_MsgUtil.callFunc("FIHGTPLAY_DEFENDER_REMOVE", self.data.index)
	end
end

function Lua_FightDebugEditItem:onAddClick(go)
	if self.data.ownType == Lua_FightDefine.FIGHT_ATTACKER then
		Lua_MsgUtil.callFunc("FIHGTPLAY_ATTACKER_ADD")
	else
		Lua_MsgUtil.callFunc("FIHGTPLAY_DEFENDER_ADD")
	end
end




















Lua_FightDebugEditVo = class("Lua_FightDebugEditVo")
function Lua_FightDebugEditVo:ctor(index, ownType, position)
	self.index = index
	self.ownType = ownType
	self.position = position
	self:init()
end

function Lua_FightDebugEditVo:init()
	if self.position == 0 then
		self.sort_id = 101
	else
		self.sort_id = 101000105
	end
	self.level = 1

	self.skill_list = {}
	for i = 1, 5 do
		self.skill_list[i] = 0
	end

	self.prop = {}
	local arr = DataCenter.attributesUtil:getDebugSetProps()
	for i = 1, arr:getSize() do
		self.prop[arr[i].id] = arr[i].defaultValue
	end
end