-- 战斗调试增加单位
Lua_FightDebugHeroWindow = class("Lua_FightDebugHeroWindow", Lua_Window)
function Lua_FightDebugHeroWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_FightDebugHeroWindow";
	self.skinName = "FightDebugHeroWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
	self.testFightId = 9876543210;
end

function Lua_FightDebugHeroWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.btnAdd_1:addClickFuntion(self, self.onAddAttacker);
	self.btnAdd_2:addClickFuntion(self, self.onAddAttackerOneKey);
	self.btnAdd_3:addClickFuntion(self, self.onAddDefender);
	self.btnAdd_4:addClickFuntion(self, self.onAddDefenderOneKey);

	self.attackerDragList = Lua_DragList.new(self.content, 600, 420, Lua_AxisDefine.Vertical);
    self.attackerDragList:setListCell(Lua_FightHeroDebugCell, 600, 60, 1);
    self.attackerDragList:setCellSpacing(10, 10);
    self.attackerDragList:setLocation(0, 215);

	self.defenderDragList = Lua_DragList.new(self.content, 600, 420, Lua_AxisDefine.Vertical);
    self.defenderDragList:setListCell(Lua_FightHeroDebugCell, 600, 60, 1);
    self.defenderDragList:setCellSpacing(10, 10);
    self.defenderDragList:setLocation(0, -315);

    self:updateAttackThings();
   	self:updateDefendThings();
   	self:addLuaEvent("fightdebug_update_removethings", self, self.onRemoveThings);
   	self:addLuaEvent("fightdebug_update_addthings", self, self.onAddThings);
end

function Lua_FightDebugHeroWindow:onAddAttacker(go)
	Lua_WindowUtil.openWin("Lua_FightDebugHeroSelectWindow", Lua_WinParam.ACTION_OPEN, Lua_FightDefine.FIGHT_ATTACKER);
end

function Lua_FightDebugHeroWindow:onAddAttackerOneKey(go)
	local thingInfo;
	local arr = Lua_HeroConfigData.getAllHeroConfig();
	for i = 1, 11 do
		thingInfo = { side = Lua_FightDefine.FIGHT_ATTACKER, heroId = arr[1].id, position = i, campId = 1 };
		self:onAddThings(thingInfo);
	end
end

function Lua_FightDebugHeroWindow:onAddDefender(go)
	Lua_WindowUtil.openWin("Lua_FightDebugHeroSelectWindow", Lua_WinParam.ACTION_OPEN, Lua_FightDefine.FIGHT_DEFENDER);
end

function Lua_FightDebugHeroWindow:onAddDefenderOneKey(go)
	local thingInfo;
	local arr = Lua_HeroConfigData.getAllHeroConfig();
	for i = 1, 11 do
		thingInfo = { side = Lua_FightDefine.FIGHT_DEFENDER, heroId = arr[1].id, position = i, campId = 1 };
		self:onAddThings(thingInfo);
	end
end

function Lua_FightDebugHeroWindow:onRemoveThings(rid)
	ThingUtil.instance:removeThing(0, self.testFightId, rid);
	self:updateAttackThings();
	self:updateDefendThings();
end

function Lua_FightDebugHeroWindow:onAddThings(thingInfo)
	-- {side = self.side, heroId = heroId, position = position, campId = campId}
	if thingInfo == nil then
		return;
	end

	if thingInfo.side == Lua_FightDefine.FIGHT_ATTACKER then
		if self.attackPosDic ~= nil and self.attackPosDic[thingInfo.position] ~= nil then
			OperateAlert.show("攻击方站位"..thingInfo.position.."已有单位");
			return;
		end
	else
		if self.defendPosDic ~= nil and self.defendPosDic[thingInfo.position] ~= nil then
			OperateAlert.show("防守方站位"..thingInfo.position.."已有单位");
			return;
		end
	end

	local spd = 1;
	if DataCenter.vipData ~= nil then
        local vipVo = DataCenter.vipData.curVipLevelVo;
        if vipVo ~= nil then
            spd = vipVo:getFightPlaySpeedByIdx(1);
        end
    end

	local data;
	if thingInfo.position == 11 then
        data = UsData();
        data.kind = Lua_ThingDefine.PLAYER;
        data.isShowName = false;
        data.artifact_id = 102;
	else
		data = HeroData();
		data.kind = Lua_ThingDefine.HERO;
		data.isShowName = true;
		data.isShowHpBar = true;
		data.isShowBuffIcon = true;
	end
    
    data.roleId = thingInfo.position + thingInfo.side * 1000;
    data.objId = tonumber(tostring(thingInfo.heroId));
    data.fightRecordId = self.testFightId;
    data.formationType = thingInfo.side;
    data.formationPos = thingInfo.position;
    data.lvl = 1;
    data.hp = 20;
    data.maxHp = 20;
    data.sceneId = Scene3DManager.instance.curShowSceneId;
    data.aniSpeed = spd;
    local campId = thingInfo.campId ~= nil and thingInfo.campId or 0;
    local cfg = Lua_FightCampPosConfig.getConfigData(campId);
    data.campPosId = campId;
    data.dir = cfg:getDirByType(thingInfo.side);
    data.px = cfg:getPosxByIdx(thingInfo.side, thingInfo.position);
    data.py = 0;
    data.pz = cfg:getPoszByIdx(thingInfo.side, thingInfo.position);
    data:refreshShowPos();
    data.showShadow = false;
    data.bPlanarShadow = false;
    data.toLand = false;
    ThingUtil.instance:addAnimal(data, true);

    if thingInfo.side == Lua_FightDefine.FIGHT_ATTACKER then
    	self:updateAttackThings();
	else
		self:updateDefendThings();
	end
	Lua_WindowUtil.openWin("Lua_FightDebugHeroSelectWindow", Lua_WinParam.ACTION_CLOSE);
end

function Lua_FightDebugHeroWindow:updateAttackThings()
	local arr = DataCenter.thingData:getThingIdsByFormationType(self.testFightId, Lua_FightDefine.FIGHT_ATTACKER);
	if arr == nil then
		arr = Array();
	end
	self.attackerDragList:setArrayData(arr);
	self.attackPosDic = {};
	for i = 1, arr:getSize() do 
		local rid = arr[i];
		local pos = rid - Lua_FightDefine.FIGHT_ATTACKER * 10;
		self.attackPosDic[pos] = rid;
	end
end

function Lua_FightDebugHeroWindow:updateDefendThings()
	local arr = DataCenter.thingData:getThingIdsByFormationType(self.testFightId, Lua_FightDefine.FIGHT_DEFENDER);
	if arr == nil then
		arr = Array();
	end
	self.defenderDragList:setArrayData(arr);
	self.defendPosDic = {};
	for i = 1, arr:getSize() do 
		local rid = arr[i];
		local pos = rid - Lua_FightDefine.FIGHT_DEFENDER * 10;
		self.defendPosDic[pos] = rid;
	end
end

function Lua_FightDebugHeroWindow:dispose()
	if self.attackerDragList ~= nil then
		self.attackerDragList:dispose();
		self.attackerDragList = nil;
	end
	if self.defenderDragList ~= nil then
		self.defenderDragList:dispose();
		self.defenderDragList = nil;
	end
	self:superCall("dispose");
end





















Lua_FightHeroDebugCell = class("Lua_FightHeroDebugCell", Lua_ListCell);
function Lua_FightHeroDebugCell:ctor(p)
    self:superCall("ctor", p);
    self.testFightId = 9876543210;
end

function Lua_FightHeroDebugCell:buildShowItem()
    self:superCall("buildShowItem");

    self.txt = UICreate.createLabel(self.content, "英雄", -300, 0, 200, 31, 22);
    self.txt.pivot = Lua_WindowUtil.getPivot(3);
    self.txt.alignmentValue = 3;
    self.txt.horizontalOverflowValue = 1;
    self.txt.colorStr = Lua_ColorDefine.transColor("846651");

    self.btn = UICreate.createButton(self.content, "移除", 200, 0, 177, 58);
    self.btn:addClickFuntion(self, self.onClickRemoveBtn);
end

function Lua_FightHeroDebugCell:onClickRemoveBtn(go)
	if self.data ~= nil then
		Lua_MsgUtil.callFunc("fightdebug_update_removethings", self.data);
	end
end

function Lua_FightHeroDebugCell:setData(data)
    self.data = data;
    local thing = DataCenter.thingData:getThingPlayer(Scene3DManager.instance.curShowSceneId, self.testFightId, self.data);
    if thing ~= nil then
    	local objId = thing.objId;
    	local cfg = Lua_HeroConfigData.getConfig(objId);
		if cfg ~= nil then
			self.txt.text = cfg.name .. "("..data.."，位置"..thing.formationPos..")";
		else
			self.txt.text = tostring(data);
		end
    else
    	self.txt.text = tostring(data);
    end
end

function Lua_FightHeroDebugCell:dispose()
    self.data = nil;
    self:superCall("dispose");
end