Lua_FightStageHeroPorpItem = class("Lua_FightStageHeroPorpItem", Lua_DisplayObject);
function Lua_FightStageHeroPorpItem:ctor(p)
    self:superCall("ctor", p, "FightStageHeroPorpItem_skin");
end

function Lua_FightStageHeroPorpItem:buildShowItem()
    self:superCall("buildShowItem");
end

function Lua_FightStageHeroPorpItem:dispose()
	self.owner = nil;
	self.callBack = nil;
	self.data = nil;
    self:superCall("dispose");
end

function Lua_FightStageHeroPorpItem:setCallBack(owner, callBack)
	self.owner = owner;
	self.callBack = callBack;
end

function Lua_FightStageHeroPorpItem.Set:propName(value)
	self._propName = value;
	if value == "hero_id" or value == "artifact_id" or value == "skill" then
		self.bg.mouseEnable = true;
		self.bg:addClickFuntion(self, self.onBgClick);
		self.txtInput.inputMouseEnable = false;
		self.txtInput:onChange(nil, nil);
	else
		self.bg.mouseEnable = false;
		self.bg:removeClickFuntion(self, self.onBgClick);
		self.txtInput.inputMouseEnable = true;
		self.txtInput:onChange(self, self.onInputClick);
	end
end

function Lua_FightStageHeroPorpItem.Get:propName()
	return self._propName;
end

function Lua_FightStageHeroPorpItem:onBgClick(go)
	Lua_WindowUtil.openWin("Lua_FightStageSetSelectWindow", Lua_WinParam.ACTION_AUTO, self.propName);
	self:addLuaEvent("FIGHTPLAY_STAGESET_SELECT", self, self.onSelectCellClick);
end

function Lua_FightStageHeroPorpItem:onInputClick()
	local val = self.txtInput.text;
	if val == nil then val = 0 end
	val = tonumber(val)
	if self.data ~= nil then
		if self.propVo ~= nil then
			self.data.prop[self.propVo.id] = val;
		else
			self.data[self.propName] = val;
			if self.owner and self.callBack then
				self.callBack(self.owner, self.propName, val);
			end
		end
	end
	self.value = val;
end

function Lua_FightStageHeroPorpItem:onSelectCellClick(data)
	if data ~= nil then
        local str = data.remark;
        if strIsNullOrEmpty(str) then
            str = data.name;
        end
		if self.propName == "skill" then -- 技能
			str = str .. "(" .. data.skillId .. ")";
			if self.data ~= nil then
				local list = self.data.skill_list;
				list[self.skillIdx] = data.skillId;
			end
		elseif self.propName == "hero_id" then -- 英雄
			self.value = data.id;
			str = str .. "(" .. data.id .. ")";
			if self.data ~= nil then
				self.data[self.propName] = data.id;
			end

			-- 采用配置默认属性和技能
		elseif self.propName == "artifact_id" then -- 神器
			self.value = data.id;
			str = str .. "(" .. data.id .. ")";
			if self.data ~= nil then
				self.data[self.propName] = data.id;
			end

			-- 采用配置默认属性和技能
		end
        self.txtInput.text = str;
	end

	self:removeLuaEvent("FIGHTPLAY_STAGESET_SELECT", self, self.onSelectCellClick);
end

function Lua_FightStageHeroPorpItem:setServerHeroInfo(data)
	self.data = data;
	local val = data[self.propName];
	if val == nil then
		self.txtInput.text = "";
	else
		if self.propName == "hero_id" then
			local cfg = Lua_HeroConfigData.getConfig(val);
			if cfg ~= nil then
				local str = cfg.remark;
				if strIsNullOrEmpty(str) then
					str = cfg.name;
				end
				self.txtInput.text = str .. "(" .. val .. ")";
			else
				self.txtInput.text = "";
			end
		elseif self.propName == "artifact_id" then
			local cfg = getConfig("artifact", val);
			if cfg ~= nil then
				local str = cfg.remark;
				if strIsNullOrEmpty(str) then
					str = cfg.name;
				end
				self.txtInput.text = str .. "(" .. val .. ")";
			else
				self.txtInput.text = "";
			end
		else
			self.txtInput.text = tostring(val);
		end
	end
end

function Lua_FightStageHeroPorpItem:setServerPropInfo(data)
	self.data = data;
	self:setValue(data.prop[self.propName]);
end

function Lua_FightStageHeroPorpItem:setServerSkillInfo(data, idx)
	self.data = data;
	self.skillIdx = idx;
	local skillId = data.skill_list[idx];
	if skillId == 0 then
		self.txtInput.text = "";
	else
		local cfg = Lua_SkillConfigData.getConfigData(skillId);
		if cfg ~= nil then
			local str = cfg.remark;
			if strIsNullOrEmpty(str) then
				str = cfg.name;
			end
			self.txtInput.text = str .. "(" .. skillId .. ")";
		else
			self.txtInput.text = "";
		end
	end
end

function Lua_FightStageHeroPorpItem:setNameTxt(str)
	if str ~= nil and #str > 10 then
		self.nameTxt.fontSize = 20;
	else
		self.nameTxt.fontSize = 26;
	end
	self.nameTxt.text = str;
end

function Lua_FightStageHeroPorpItem:setValue(val)
	self.value = val;
	self.txtInput.text = tostring(val);
end

function Lua_FightStageHeroPorpItem:setPropVo(vo)
	self.propVo = vo;
	self:setNameTxt(vo.show_name);
end