-- 消息号解析界面
Lua_MsgDecodeWindow = class("Lua_MsgDecodeWindow", Lua_Window);
function Lua_MsgDecodeWindow:ctor()
    self:superCall("ctor");

    self.isFullPaving = true;
    self.isFullSizeWin = true;
    self.windowName = "Lua_MsgDecodeWindow";
    self.skinName = "MsgDecodeWindow_skin";
    self.showBlackMask = true;
    self.showWinBg = true;
    self.showClose = true;
    self.idSort = false;
    self.timeSort = true; -- 时间优先级高于id
    self.dataPath = LanUtil.StringProfile3(UnityEngine.Application.dataPath, "/StreamingAssets/msg.txt");
end

function Lua_MsgDecodeWindow:buildShowItem()
    self:superCall("buildShowItem");
    self:addLuaEvent("MsgDecode_Select", self, self.onSelectDecodeMsg);

    if GlobalVar.bWriteMsg then
		self.recordbtn.label = "取消保存消息";
	else
		self.recordbtn.label = "保存消息内容";
	end
    
    self.shaixuanTxt.text = "";
    self.shaixuanTxt:ActivateInputField();
    self.shaixuanTxt:onChange(self, self.onCheckList);
    self.idTitle:addClickFuntion(self, self.onIdClick);
    self.timeTitle:addClickFuntion(self, self.onTimeClick);
    self.refreshBtn:addClickFuntion(self, self.onRefreshClick);
    self.recordbtn:addClickFuntion(self, self.onRecordBtnClick);
    self.delMsgBtn:addClickFuntion(self, self.onDelMsgClick);
    self.copyBtn:addClickFuntion(self, self.onCopyClick);
    self.sendBtn:addClickFuntion(self, self.onSendClick);
    self.sendBtn:setEnable(false);
    self.copyBtn:setEnable(false);

    self.dragList = Lua_DragList.new(self.content, 700, 415, Lua_AxisDefine.Vertical);
    self.dragList:setListCell(Lua_MsgDecodeCell, 700, 60, 1);
    self.dragList:setLocation(0, -357);
    self.dragList:setRectAnchor(1);

    self:decodeMsgInfo();
    self.refreshClickTime = getTime();
    self:showMsg(nil, self.idSort, self.timeSort);
end

function Lua_MsgDecodeWindow:dispose()
	if self.decodeMsgArr ~= nil then
		self.decodeMsgArr:clear();
		self.decodeMsgArr:dispose();
		self.decodeMsgArr = nil;
	end

	if self.showMsgArr ~= nil then
		self.showMsgArr:clear();
		self.showMsgArr:dispose();
		self.showMsgArr = nil;
	end

    if self.dragList ~= nil then
        self.dragList:dispose();
        self.dragList = nil;
    end

    if self.textArea ~= nil then
    	self.textArea:dispose();
    	self.textArea = nil;
    end

    self:superCall("dispose");
end

-- 列表筛选
function Lua_MsgDecodeWindow:onCheckList()
	self:showMsg(self.shaixuanTxt.text, self.idSort, self.timeSort);
end

-- id排序
function Lua_MsgDecodeWindow:onIdClick()
	self.idSort = true;
	self.timeSort = false;
	self:showMsg(self.shaixuanTxt.text, self.idSort, self.timeSort);
end

-- 时间排序，默认
function Lua_MsgDecodeWindow:onTimeClick()
	self.idSort = false;
	self.timeSort = true;
	self:showMsg(self.shaixuanTxt.text, self.idSort, self.timeSort);
end

-- 保存消息号
function Lua_MsgDecodeWindow:onRecordBtnClick()
	local bWriteMsg = GlobalVar.bWriteMsg;
	GlobalVar.bWriteMsg = not bWriteMsg;
	if GlobalVar.bWriteMsg then
		self.recordbtn.label = "取消保存消息";
	else
		self.recordbtn.label = "保存消息内容";
	end
end

-- 删除本地记录
function Lua_MsgDecodeWindow:onDelMsgClick()
	LuaUtil.deleteFile(UnityEngine.Application.dataPath .. "/StreamingAssets/msg.txt");
end

-- 刷新
function Lua_MsgDecodeWindow:onRefreshClick()
	if self.refreshClickTime ~= nil and getTime() - self.refreshClickTime < 2 then
		OperateAlert.show("稍后点击刷新");
		return;
	end

	self.lastMsg = nil;
	self.sendBtn:setEnable(false);
    self.copyBtn:setEnable(false);
	if self.textArea ~= nil then
		self.textArea:setText("");
	end

	self:decodeMsgInfo();
	self.refreshClickTime = getTime();
	self:showMsg(self.shaixuanTxt.text, self.idSort, self.timeSort);
end

function Lua_MsgDecodeWindow:decodeMsgInfo()
	if self.decodeMsgArr ~= nil then
		self.decodeMsgArr:clear();
	end
	local str = LuaUtil.readLocalFile(self.dataPath);
	if strIsNullOrEmpty(str) then 
		return; 
	end

	local numDic = {};
	local arr = string.split(str, "\r\n");
	if arr ~= nil then
		for i = 1, arr:getSize() do
			local msgStr = arr[i];
			if not strIsNullOrEmpty(msgStr) then
				local msgArr = string.split(msgStr, "：");
				if msgArr ~= nil and msgArr:getSize() == 2 then
					local msgContent = msgArr[2];	
					local msgIdStr = msgArr[1];
					local arr2 = string.split(msgIdStr, "_");
					local msgId = tonumber(arr2[1]);
					local time = arr2[2];
					local timerStamp = self:dataToTimeStamp(time);
					if self.decodeMsgArr == nil then self.decodeMsgArr = Array(); end
					self.decodeMsgArr:add({index = i, msgId = msgId, time = time, timerStamp = timerStamp, msgContent = msgContent});
					if numDic[msgId] == nil then
						numDic[msgId] = 1;
					else
						numDic[msgId] = numDic[msgId] + 1;
					end
				end
			end
		end
	end

	-- for i = 1, self.decodeMsgArr:getSize() do
	-- 	local info = self.decodeMsgArr[i];
	-- 	info.index = numDic[info.msgId];
	-- end
end

function Lua_MsgDecodeWindow:trim(s)
    -- return (s:gsub("^%s*(.-)%s*$", "%1"))
    return (s:gsub("^%s*(./)%s*$", "%1"))
end

-- 日期时间转时间戳 注意输出格式是xxxx-02-12 09:30:12
-- 参数可以是  “xxxx-02-12 09:30:12” 或者 表{2019,2,12,9,30,12}
function Lua_MsgDecodeWindow:dataToTimeStamp(dataStr)
    local result = -1
    local tempTable = {}

    if dataStr == nil then
        error("传递进来的日期时间参数不合法")
    elseif type(dataStr) == "string" then
        dataStr = trim(dataStr)
        for v in string.gmatch(dataStr, "%d+") do
            tempTable[#tempTable + 1] = v
        end
    elseif type(dataStr) == "table" then
        tempTable = dataStr
    else
        error("传递进来的日期时间参数不合法")
    end

    result = os.time({
        day = tonumber(tempTable[3]),
        month = tonumber(tempTable[2]),
        year = tonumber(tempTable[1]),
        hour = tonumber(tempTable[4]),
        min = tonumber(tempTable[5]),
        sec = tonumber(tempTable[6])
    })
    return result
end


function Lua_MsgDecodeWindow:showMsg(msgId, sortId, sortTime)
	if self.showMsgArr == nil then
		self.showMsgArr = Array();
	else
		self.showMsgArr:clear();
	end

	if self.decodeMsgArr == nil then
		return;
	end

	for i = 1, self.decodeMsgArr:getSize() do
		local msg = self.decodeMsgArr[i];
		if not strIsNullOrEmpty(msgId) then 
			if string.find(msg.msgId, msgId) ~= nil then
				self.showMsgArr:add(msg);
			end
		else
			self.showMsgArr:add(msg);
		end
	end

	if sortId then
		self.showMsgArr:sort("msgId", false);
	elseif sortTime then
		self.showMsgArr:sort("timerStamp", true);
	end
	self.dragList:setArrayData(self.showMsgArr);
end

-- 解析消息号内容
function Lua_MsgDecodeWindow:onSelectDecodeMsg(msg)
	if msg == nil then return; end
	if self.lastMsg ~= nil and self.lastMsg == msg then
		OperateAlert.show("已解析该消息");
		return;
	end

	self.lastMsg = msg;
	local str = self.lastMsg.parseMsgStr;
	if str == nil then
		str = "索引：" .. msg.index .. "\n消息号ID：" .. msg.msgId .. "\n时间：" .. msg.time .. "\n内容解析：\n";
		-- 解析消息号内容
		local msgContent = msg.msgContent;
		if not strIsNullOrEmpty(msgContent) then
			local mp = LuaUtil.parseMsgString(msg.msgId, msgContent);
			if mp ~= nil then
				local pb = getProtoMsg("Proto"..msg.msgId);
				if pb ~= nil then
		            pb:ParseFromString(mp.data);
		            str = str .. msgToString(pb);
		        end
		    else
		    	str = str .. "无内容";
			end
		end
	end

	if self.textArea == nil then
		self.textArea = Lua_TextArea.new(self.content, 670, 730);
		self.textArea:setLocation(0, -1033, 0);
		self.textArea:setRectAnchor(1);
		self.textArea:setSiblingIndex(self.copyBtn.siblingIndex);
	end
	self.lastMsg.parseMsgStr = str;
	self.textArea:setText(str);
	self.sendBtn:setEnable(msg.msgId < 50000000);
    self.copyBtn:setEnable(true);
end

function Lua_MsgDecodeWindow:onCopyClick()
	if self.lastMsg == nil then
		OperateAlert.show("请先选择解析消息号");
		return;
	end

	if self.textArea ~= nil then
		LanUtil.copyToClipboard(self.lastMsg.parseMsgStr);
		OperateAlert.show("拷贝成功");
	end
end

function Lua_MsgDecodeWindow:onSendClick()
	if self.lastMsg == nil then return; end
	if self.lastMsg.msgId >= 50000000 then return; end
	Lua_WindowUtil.openWin("Lua_MsgSimulateSendWindow", Lua_WinParam.ACTION_OPEN, self.lastMsg);
end

















Lua_MsgDecodeCell = class("Lua_MsgDecodeCell", Lua_ListCell);
function Lua_MsgDecodeCell:ctor(p)
    self:superCall("ctor", p, "MsgDecodeCell_skin");
end

function Lua_MsgDecodeCell:buildShowItem()
    self:superCall("buildShowItem");

    self.decodeBtn:addClickFuntion(self, self.onDecodeClick);
    self.copyBtn:addClickFuntion(self, self.onCopyClick);
    self.sendBtn:addClickFuntion(self, self.onSendClick);
    self.sendBtn:setEnable(false);
end

function Lua_MsgDecodeCell:setData(data)
    self._data = data;
    if data == nil then
	    self.msgId.text = "";
	    self.timeTxt.text = "";
	    self.indexTxt.text = "";
	    self.sendBtn:setEnable(false);
	else
		self.msgId.text = data.msgId .. "";
	    self.timeTxt.text = data.time;
	    self.indexTxt.text = data.index .. "";
	    self.sendBtn:setEnable(data.msgId < 50000000);
	end
end

function Lua_MsgDecodeCell:dispose(go)
	self._data = nil;
    self:superCall("dispose");
end

function Lua_MsgDecodeCell:onCopyClick()
	if self._data == nil then return; end
	LanUtil.copyToClipboard(self._data.msgContent);
	OperateAlert.show("拷贝成功");
end

function Lua_MsgDecodeCell:onDecodeClick()
	if self._data == nil then return; end
	Lua_MsgUtil.callFunc("MsgDecode_Select", self._data);
end

function Lua_MsgDecodeCell:onSendClick()
	if self._data == nil then return; end
	if self._data.msgId >= 50000000 then return; end
	Lua_WindowUtil.openWin("Lua_MsgSimulateSendWindow", Lua_WinParam.ACTION_OPEN, self._data);
end